<?php

$LANG = array(
    'organization' => 'Empresa',
    'name' => 'Nombre',
    'website' => 'Sitio Web',
    'work_phone' => 'Teléfono',
    'address' => 'Dirección',
    'address1' => 'Calle',
    'address2' => 'Bloq/Pta',
    'city' => 'Ciudad',
    'state' => 'Región/Provincia',
    'postal_code' => 'Código Postal',
    'country_id' => 'País',
    'contacts' => 'Contactos',
    'first_name' => 'Nombres',
    'last_name' => 'Apellidos',
    'phone' => 'Teléfono',
    'email' => 'Correo Electrónico',
    'additional_info' => 'Información Adicional',
    'payment_terms' => 'Términos de Pago',
    'currency_id' => 'Divisa',
    'size_id' => 'Tamaño de la Empresa',
    'industry_id' => 'Industria',
    'private_notes' => 'Notas Privadas',
    'invoice' => 'Factura',
    'client' => 'Cliente',
    'invoice_date' => 'Fecha de Factura',
    'due_date' => 'Fecha de Pago',
    'invoice_number' => 'Número de Factura',
    'invoice_number_short' => 'Factura #',
    'po_number' => 'Número de Orden',
    'po_number_short' => 'Orden #',
    'frequency_id' => 'Frecuencia',
    'discount' => 'Descuento',
    'taxes' => 'Impuestos',
    'tax' => 'Impuesto',
    'item' => 'Concepto',
    'description' => 'Descripción',
    'unit_cost' => 'Coste unitario',
    'quantity' => 'Cantidad',
    'line_total' => 'Total',
    'subtotal' => 'Subtotal',
    'paid_to_date' => 'Pagado',
    'balance_due' => 'Pendiente',
    'invoice_design_id' => 'Diseño',
    'terms' => 'Términos',
    'your_invoice' => 'Tu factura',
    'remove_contact' => 'Eliminar contacto',
    'add_contact' => 'Añadir contacto',
    'create_new_client' => 'Crear nuevo cliente',
    'edit_client_details' => 'Editar detalles del cliente',
    'enable' => 'Activar',
    'learn_more' => 'Saber más',
    'manage_rates' => 'Gestionar tarifas',
    'note_to_client' => 'Nota para el cliente',
    'invoice_terms' => 'Términos de Facturación',
    'save_as_default_terms' => 'Guardar como términos por defecto',
    'download_pdf' => 'Descargar PDF',
    'pay_now' => 'Pagar ahora',
    'save_invoice' => 'Guardar factura',
    'clone_invoice' => 'Clonar como Factura',
    'archive_invoice' => 'Archivar Factura',
    'delete_invoice' => 'Eliminar Factura',
    'email_invoice' => 'Enviar factura por correo',
    'enter_payment' => 'Agregar Pago',
    'tax_rates' => 'Tasas de Impuesto',
    'rate' => 'Tasas',
    'settings' => 'Configuración',
    'enable_invoice_tax' => 'Activar impuesto <b>para la factura</b>',
    'enable_line_item_tax' => 'Activar impuesto <b>por concepto</b>',
    'dashboard' => 'Inicio',
    'dashboard_totals_in_all_currencies_help' => 'Nota: Agregue un nombre para el :link  ":name" para mostrar los totales usando una moneda base única.',
    'clients' => 'Clientes',
    'invoices' => 'Facturas',
    'payments' => 'Pagos',
    'credits' => 'Créditos',
    'history' => 'Historial',
    'search' => 'Búsqueda',
    'sign_up' => 'Registrarse',
    'guest' => 'Invitado',
    'company_details' => 'Detalles de la Empresa',
    'online_payments' => 'Pagos Online',
    'notifications' => 'Notificaciones',
    'import_export' => 'Importar/Exportar',
    'done' => 'Hecho',
    'save' => 'Guardar',
    'create' => 'Crear',
    'upload' => 'Subir',
    'import' => 'Importar',
    'download' => 'Descargar',
    'cancel' => 'Cancelar',
    'close' => 'Cerrar',
    'provide_email' => 'Por favor facilita una dirección de correo electrónico válida.',
    'powered_by' => 'Plataforma por',
    'no_items' => 'No hay ítems',
    'recurring_invoices' => 'Facturas Recurrentes',
    'recurring_help' => '<p>Envía automáticamente a los clientes las mismas facturas semanal, bi-mensual, mensual, trimestral o anualmente </p>
        <p>Usa :MONTH, :QUARTER o :YEAR para las fechas dinámicas. Matemática básica también funciona, por ejemplo :MONTH-1.</p>
        <p>Ejemplos de variables de factura dinámica:</p>
        <ul>
          <li>"Membresía al gimnasio por el mes de :MONTH" >> "Membresía al gimnasio para el mes de Julio"</li>
          <li>":YEAR+1 subscripción anual" >> "2015 Subscripción Anual"</li>
          <li>"Pago de retención para :QUARTER+1" >> "Pago de retención para el segundo trimestre</li>
        </ul>',
    'recurring_quotes' => 'Cotizaciones Recurrentes',
    'in_total_revenue' => 'Ingreso Total',
    'billed_client' => 'Cliente Facturado',
    'billed_clients' => 'Clientes Facturados',
    'active_client' => 'Cliente Activo',
    'active_clients' => 'Clientes Activos',
    'invoices_past_due' => 'Facturas Vencidas',
    'upcoming_invoices' => 'Próximas Facturas',
    'average_invoice' => 'Promedio de Facturación',
    'archive' => 'Archivar',
    'delete' => 'Eliminar',
    'archive_client' => 'Archivar Cliente',
    'delete_client' => 'Eliminar Cliente',
    'archive_payment' => 'Archivar Pago',
    'delete_payment' => 'Eliminar Pago',
    'archive_credit' => 'Archivar Crédito',
    'delete_credit' => 'Eliminar Crédito',
    'show_archived_deleted' => 'Mostrar archivados/eliminados en ',
    'filter' => 'Filtrar',
    'new_client' => 'Nuevo Cliente',
    'new_invoice' => 'Nueva Factura',
    'new_payment' => 'Ingresa el Pago',
    'new_credit' => 'Ingresa el Crédito',
    'contact' => 'Contacto',
    'date_created' => 'Fecha de Creación',
    'last_login' => 'Último Acceso',
    'balance' => 'Saldo',
    'action' => 'Acción',
    'status' => 'Estado',
    'invoice_total' => 'Total Facturado',
    'frequency' => 'Frequencia',
    'range' => 'Rango',
    'start_date' => 'Fecha de Inicio',
    'end_date' => 'Fecha de Finalización',
    'transaction_reference' => 'Referencia de Transacción',
    'method' => 'Método',
    'payment_amount' => 'Valor del Pago',
    'payment_date' => 'Fecha de Pago',
    'credit_amount' => 'Cantidad de Crédito',
    'credit_balance' => 'Saldo de Crédito',
    'credit_date' => 'Fecha de Crédito',
    'empty_table' => 'Tabla vacía',
    'select' => 'Seleccionar',
    'edit_client' => 'Editar Cliente',
    'edit_invoice' => 'Editar Factura',
    'create_invoice' => 'Crear Factura',
    'enter_credit' => 'Agregar Crédito',
    'last_logged_in' => 'Último inicio de sesión',
    'details' => 'Detalles',
    'standing' => 'Situación',
    'credit' => 'Crédito',
    'activity' => 'Actividad',
    'date' => 'Fecha',
    'message' => 'Mensaje',
    'adjustment' => 'Ajustes',
    'are_you_sure' => '¿Estás Seguro?',
    'payment_type_id' => 'Tipo de pago',
    'amount' => 'Cantidad',
    'work_email' => 'Correo electrónico de la empresa',
    'language_id' => 'Idioma',
    'timezone_id' => 'Zona Horaria',
    'date_format_id' => 'Formato de Fecha',
    'datetime_format_id' => 'Formato de Fecha/Hora',
    'users' => 'Usuarios',
    'localization' => 'Localización',
    'remove_logo' => 'Eliminar logo',
    'logo_help' => 'Formatos aceptados: JPEG, GIF y PNG',
    'payment_gateway' => 'Pasarela de pago',
    'gateway_id' => 'Proveedor',
    'email_notifications' => 'Notificaciones de correo',
    'email_sent' => 'Avísame por correo cuando una factura <b>se envía</b>',
    'email_viewed' => 'Avísame por correo cuando una factura <b>se visualiza</b>',
    'email_paid' => 'Avísame por correo cuando una factura <b>se paga</b>',
    'site_updates' => 'Actualizaciones del sitio',
    'custom_messages' => 'Mensajes a medida',
    'default_email_footer' => 'Configurar <b>firma de correo</b> por defecto',
    'select_file' => 'Por favor selecciona un archivo',
    'first_row_headers' => 'Usar la primera fila como encabezados',
    'column' => 'Columna',
    'sample' => 'Ejemplo',
    'import_to' => 'Importar a',
    'client_will_create' => 'cliente será creado',
    'clients_will_create' => 'clientes serán creados',
    'email_settings' => 'Configuración del Correo Electrónico',
    'client_view_styling' => 'Estilo de Visualización para el Cliente',
    'pdf_email_attachment' => 'Adjuntar PDF',
    'custom_css' => 'CSS Personalizado',
    'import_clients' => 'Importar Datos del Cliente',
    'csv_file' => 'Seleccionar archivo CSV',
    'export_clients' => 'Exportar Datos del Cliente',
    'created_client' => 'cliente creado con éxito',
    'created_clients' => ':count clientes creados con éxito',
    'updated_settings' => 'Configuración actualizada con éxito',
    'removed_logo' => 'Logo eliminado con éxito',
    'sent_message' => 'Mensaje enviado con éxito',
    'invoice_error' => 'Seleccionar cliente y corregir errores.',
    'limit_clients' => 'Lo sentimos, se ha pasado del límite de :count clientes',
    'payment_error' => 'Ha habido un error en el proceso de tu pago. Inténtalo de nuevo más tarde.',
    'registration_required' => 'Inscríbete para enviar una factura',
    'confirmation_required' => 'Por favor confirma tu dirección de correo electrónico, :link para reenviar el correo de confirmación.',
    'updated_client' => 'Cliente actualizado con éxito',
    'archived_client' => 'Cliente archivado con éxito',
    'archived_clients' => ':count clientes archivados con éxito',
    'deleted_client' => 'Cliente eliminado con éxito',
    'deleted_clients' => ':count clientes eliminados con éxito',
    'updated_invoice' => 'Factura actualizada con éxito',
    'created_invoice' => 'Factura creada con éxito',
    'cloned_invoice' => 'Factura clonada con éxito',
    'emailed_invoice' => 'Factura enviada con éxito',
    'and_created_client' => 'y cliente creado ',
    'archived_invoice' => 'Factura archivada con éxito',
    'archived_invoices' => ':count facturas archivados con éxito',
    'deleted_invoice' => 'Factura eliminada con éxito',
    'deleted_invoices' => ':count facturas eliminadas con éxito',
    'created_payment' => 'Pago creado con éxito',
    'created_payments' => ':count pagos creados con éxito',
    'archived_payment' => 'Pago archivado con éxito',
    'archived_payments' => ':count pagos archivados con éxito',
    'deleted_payment' => 'Pago eliminado con éxito',
    'deleted_payments' => ':count pagos eliminados con éxito',
    'applied_payment' => 'Pago aplicado con éxito',
    'created_credit' => 'Crédito creado con éxito',
    'archived_credit' => 'Crédito archivado con éxito',
    'archived_credits' => ':count creditos archivados con éxito',
    'deleted_credit' => 'Créditos eliminados con éxito',
    'deleted_credits' => ':count creditos eliminados con éxito',
    'imported_file' => 'Archivo importado con éxito',
    'updated_vendor' => 'Proveedor actualizado con éxito',
    'created_vendor' => 'Proveedor creado con éxito',
    'archived_vendor' => 'Proveedor archivado con éxito',
    'archived_vendors' => ':count proveedores actualizados con éxito',
    'deleted_vendor' => 'Proveedor eliminado con éxito',
    'deleted_vendors' => ':count proveedores actualizados con éxito',
    'confirmation_subject' => 'Corfimación de tu cuenta en Invoice Ninja',
    'confirmation_header' => 'Confirmación de Cuenta',
    'confirmation_message' => 'Por favor, haz clic en el enlace abajo para confirmar tu cuenta.',
    'invoice_subject' => 'Nueva factura :invoice de :account',
    'invoice_message' => 'Para visualizar tu factura por el valor de :amount, haga click en el enlace a continuación.',
    'payment_subject' => 'Pago recibido',
    'payment_message' => 'Gracias por tu pago de :amount.',
    'email_salutation' => 'Estimado :name,',
    'email_signature' => 'Un cordial saludo,',
    'email_from' => 'El equipo de Invoice Ninja ',
    'invoice_link_message' => 'Para visualizar la factura de cliente, haz clic en el enlace a continuación:',
    'notification_invoice_paid_subject' => 'La factura :invoice ha sido pagada por el cliente :client',
    'notification_invoice_sent_subject' => 'La factura :invoice ha sido enviada a el cliente :client',
    'notification_invoice_viewed_subject' => 'La factura :invoice ha sido visualizada por el cliente:client',
    'notification_invoice_paid' => 'Un pago por importe de :amount ha sido realizado por el cliente :client correspondiente a la factura :invoice.',
    'notification_invoice_sent' => 'La factura :invoice por importe de :amount fue enviada al cliente :cliente.',
    'notification_invoice_viewed' => 'La factura :invoice por importe de :amount fue visualizada por el cliente :client.',
    'reset_password' => 'Puedes reconfigurar la contraseña de tu cuenta haciendo clic en el siguiente enlace:',
    'secure_payment' => 'Pago seguro',
    'card_number' => 'Número de tarjeta',
    'expiration_month' => 'Mes de caducidad',
    'expiration_year' => 'Año de caducidad',
    'cvv' => 'CVV',
    'logout' => 'Cerrar sesión',
    'sign_up_to_save' => 'Registrate para guardar tu trabajo',
    'agree_to_terms' => 'Estoy de acuerdo con los :terms',
    'terms_of_service' => 'Términos de Servicio',
    'email_taken' => 'Esta dirección de correo electrónico ya se ha registrado',
    'working' => 'Procesando',
    'success' => 'Éxito',
    'success_message' => 'Te has registrado exitosamente. Por favor, haz clic en el enlace del correo de confirmación para verificar tu dirección de correo electrónico.',
    'erase_data' => 'Tu cuenta no está registrada, esto borrara todos los datos permanentemente. ',
    'password' => 'Contraseña',
    'pro_plan_product' => 'Plan Pro',
    'pro_plan_success' => '¡Gracias por unirte a Invoice Ninja! Al realizar el pago de tu factura, se iniciara tu Plan Pro !.<p/>&nbsp;<br/>
                          <b>Siguientes Pasos</b><p/>Una factura exigible ha sido enviada al correo
                          electrónico asociado con tu cuenta. Para desbloquear todas las increíbles funciones del plan Pro, por favor sigue las instrucciones en la factura para pagar
                          por un año del plan Pro.<p/>
                          No puedes encontrar la factura ? Necesitas más ayuda? Estamos felices de ayudarte
                          -- mándanos un correo a contact@invoiceninja.com',
    'unsaved_changes' => 'Tienes cambios no guardados',
    'custom_fields' => 'Campos personalizados',
    'company_fields' => 'Campos de la Empresa',
    'client_fields' => 'Campos del cliente',
    'field_label' => 'Etiqueta del campo',
    'field_value' => 'Valor del campo',
    'edit' => 'Editar',
    'set_name' => 'Indique el nombre de su empresa',
    'view_as_recipient' => 'Ver como destinitario',
    'product_library' => 'Inventario de productos',
    'product' => 'Producto',
    'products' => 'Productos',
    'fill_products' => 'Auto-rellenar productos',
    'fill_products_help' => 'Seleccionar un producto automáticamente <b>configurará la descripción y coste</b>',
    'update_products' => 'Auto-actualizar productos',
    'update_products_help' => 'Actualizar una factura automáticamente <b>actualizará los productos</b>',
    'create_product' => 'Crear Producto',
    'edit_product' => 'Editar Producto',
    'archive_product' => 'Archivar Producto',
    'updated_product' => 'Producto actualizado con éxito',
    'created_product' => 'Producto creado con éxito',
    'archived_product' => 'Producto archivado con éxito',
    'pro_plan_custom_fields' => ':link haz click para para activar campos a medida',
    'advanced_settings' => 'Configuración Avanzada',
    'pro_plan_advanced_settings' => ':link haz clic para para activar la configuración avanzada',
    'invoice_design' => 'Diseño de factura',
    'specify_colors' => 'Especificar colores',
    'specify_colors_label' => 'Seleccionar los colores para usar en las facturas',
    'chart_builder' => 'Constructor de graficos',
    'ninja_email_footer' => 'Creado por :site | Crear. Enviar. Recibir Pago.',
    'go_pro' => 'Hazte Pro',
    'quote' => 'Cotización',
    'quotes' => 'Cotizaciones',
    'quote_number' => 'Numero de cotización',
    'quote_number_short' => 'Cotización #',
    'quote_date' => 'Fecha cotización',
    'quote_total' => 'Total cotizado',
    'your_quote' => 'Tu cotización',
    'total' => 'Total',
    'clone' => 'Clon',
    'new_quote' => 'Nueva cotización',
    'create_quote' => 'Crear Cotización',
    'edit_quote' => 'Editar Cotización',
    'archive_quote' => 'Archivar Cotización',
    'delete_quote' => 'Eliminar Cotización',
    'save_quote' => 'Guardar Cotización',
    'email_quote' => 'Enviar Cotización',
    'clone_quote' => 'Clonar Como Cotización',
    'convert_to_invoice' => 'Convertir a Factura',
    'view_invoice' => 'Ver Factura',
    'view_client' => 'Ver Cliente',
    'view_quote' => 'Ver Cotización',
    'updated_quote' => 'Cotización actualizada con éxito',
    'created_quote' => 'Cotización creada con éxito',
    'cloned_quote' => 'Cotización clonada con éxito',
    'emailed_quote' => 'Cotización enviada con éxito',
    'archived_quote' => 'Cotización archivada con éxito',
    'archived_quotes' => ':count cotizaciones archivadas con exito',
    'deleted_quote' => 'Cotizaciónes eliminadas con éxito',
    'deleted_quotes' => ':count cotizaciones eliminadas con exito',
    'converted_to_invoice' => 'Cotización convertida a factura con éxito',
    'quote_subject' => 'Nuevo presupuesto :quote de :account',
    'quote_message' => 'Para visualizar la cotización por valor de :amount, haz click en el enlace abajo.',
    'quote_link_message' => 'Para visualizar tu cotización haz click en el enlace abajo:',
    'notification_quote_sent_subject' => 'Cotización :invoice enviada a el cliente :client',
    'notification_quote_viewed_subject' => 'Cotización :invoice visualizada por el cliente :client',
    'notification_quote_sent' => 'La cotización :invoice por un valor de :amount, ha sido enviada al cliente :client.',
    'notification_quote_viewed' => 'La cotizacion :invoice por un valor de :amount ha sido visualizada por el cliente :client.',
    'session_expired' => 'Tu sesión ha caducado.',
    'invoice_fields' => 'Campos de Factura',
    'invoice_options' => 'Opciones de Factura',
    'hide_paid_to_date' => 'Ocultar Valor Pagado a la Fecha',
    'hide_paid_to_date_help' => 'Solo mostrar la opción “Pagado a la fecha” en sus facturas cuando se ha recibido un pago.',
    'charge_taxes' => 'Cargar Impuestos',
    'user_management' => 'Gestión de Usuarios',
    'add_user' => 'Añadir Usuario',
    'send_invite' => 'Enviar Invitación',
    'sent_invite' => 'Invitación enviada con éxito',
    'updated_user' => 'Usario actualizado con éxito',
    'invitation_message' => ':invitor te ha invitado a unirte a su cuenta en Invoice Ninja.',
    'register_to_add_user' => 'Regístrate para aregar un usuario',
    'user_state' => 'Estado',
    'edit_user' => 'Editar Usario',
    'delete_user' => 'Eliminar Usario',
    'active' => 'Activo',
    'pending' => 'Pendiente',
    'deleted_user' => 'Usario eliminado con éxito',
    'confirm_email_invoice' => '¿Estás seguro que quieres enviar esta factura?',
    'confirm_email_quote' => '¿Estás seguro que quieres enviar esta cotización?',
    'confirm_recurring_email_invoice' => 'Se ha marcado esta factura como recurrente, estás seguro que quieres enviar esta factura?',
    'confirm_recurring_email_invoice_not_sent' => 'Estás seguro de querer iniciar la recurrencia?',
    'cancel_account' => 'Cancelar Cuenta',
    'cancel_account_message' => 'AVISO: Esta acción eliminará tu cuenta de forma permanente.',
    'go_back' => 'Atrás',
    'data_visualizations' => 'Visualización de Datos',
    'sample_data' => 'Datos de Ejemplo',
    'hide' => 'Ocultar',
    'new_version_available' => 'Una nueva versión de :releases_link disponible. Estás utilizando versión :user_version, la última versión es :latest_version',
    'invoice_settings' => 'Configuración de Facturas',
    'invoice_number_prefix' => 'Prefijo de facturación',
    'invoice_number_counter' => 'Numeración de facturación',
    'quote_number_prefix' => 'Prefijo de Cotizaciones',
    'quote_number_counter' => 'Numeración de Cotizaciones',
    'share_invoice_counter' => 'Compartir la numeración para cotización y facturación',
    'invoice_issued_to' => 'Factura emitida a',
    'invalid_counter' => 'Para evitar posibles conflictos, por favor crea un prefijo de facturación y de cotización.',
    'mark_sent' => 'Marcar como enviado',
    'gateway_help_1' => ':link para registrarse con Authorize.net.',
    'gateway_help_2' => ':link para registrarse con Authorize.net.',
    'gateway_help_17' => ':link para obtener su firma del API de PayPal.',
    'gateway_help_27' => ':link para suscribirte a 2Checkout.com. Para asegurarte que los pagos puedan ser reastreados configura :complete_link como la URL de redirección en Account > Site Management en el portal de 2Checkout.',
    'gateway_help_60' => ':link para crear una cuenta WePay.',
    'more_designs' => 'Más diseños',
    'more_designs_title' => 'Diseños Adicionales de Facturas',
    'more_designs_cloud_header' => 'Pase a Pro para más diseños de facturas',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Comprar',
    'bought_designs' => 'Diseños adicionales de facturas agregados con éxito',
    'sent' => 'Enviado',
    'vat_number' => 'CIF/NIF',
    'timesheets' => 'Hojas de Tiempo',
    'payment_title' => 'Ingresa la Dirección de Facturación de tu Tareta de Crédito',
    'payment_cvv' => '*Este es el dígito de 3-4 números en la parte trasera de su tarjeta',
    'payment_footer1' => '*La dirección debe coincidir con la dirección asociada a la tarjeta de crédito.',
    'payment_footer2' => '*Por favor haz clic en "PAGAR AHORA" sólo una vez - la transacción puede demorarse hasta un minuto en ser procesada.',
    'id_number' => 'ID Number',
    'white_label_link' => 'Etiqueta Blanca',
    'white_label_header' => 'Etiqueta Blanca',
    'bought_white_label' => 'Licencia de etiqueta blanca habilitada con éxito',
    'white_labeled' => 'Etiqueta Blanca',
    'restore' => 'Restaurar',
    'restore_invoice' => 'Restaurar Factura',
    'restore_quote' => 'Restaurar Cotización',
    'restore_client' => 'Restaurar Cliente',
    'restore_credit' => 'Restaurar Crédito',
    'restore_payment' => 'Restaurar Pago',
    'restored_invoice' => 'Factura restaurada con éxito',
    'restored_quote' => 'Cotización restaurada con éxito',
    'restored_client' => 'Cliente restaurado con éxito',
    'restored_payment' => 'Pago restaurado con éxito',
    'restored_credit' => 'Crédito restaurado con éxito',
    'reason_for_canceling' => 'Ayúdenos a mejorar contándonos porqué se va.',
    'discount_percent' => 'Porcentaje',
    'discount_amount' => 'Cantidad',
    'invoice_history' => 'Historial de Facturas',
    'quote_history' => 'Historial de Cotizaciones',
    'current_version' => 'Versión Actual',
    'select_version' => 'Seleccione la Versión',
    'view_history' => 'Ver Historial',
    'edit_payment' => 'Editar Pago',
    'updated_payment' => 'Pago actualizado con éxito',
    'deleted' => 'Eliminado',
    'restore_user' => 'Restaurar Usuario',
    'restored_user' => 'Usuario restaurado con éxito',
    'show_deleted_users' => 'Mostrar usuarios eliminados',
    'email_templates' => 'Plantillas de Correo',
    'invoice_email' => 'Correo de Factura',
    'payment_email' => 'Correo de Pago',
    'quote_email' => 'Correo de Cotizacion',
    'reset_all' => 'Reiniciar Todos',
    'approve' => 'Aprobar',
    'token_billing_type_id' => 'Token de Facturación',
    'token_billing_help' => 'Guardar detalles de pago con WePay, Stripe Braintree o GoCardless.',
    'token_billing_1' => 'Deshabilitado',
    'token_billing_2' => 'Opt-in - el checkbox es mostrado pero no seleccionado',
    'token_billing_3' => 'Opt-out - el checkbox es mostrado y seleccionado',
    'token_billing_4' => 'Siempre',
    'token_billing_checkbox' => 'Almacenar detalles de la tarjeta de crédito',
    'view_in_gateway' => 'Ver en :gateway',
    'use_card_on_file' => 'Use Card on File',
    'edit_payment_details' => 'Editar detalles del pago',
    'token_billing' => 'Guardar detalles de la tarjeta',
    'token_billing_secure' => 'La información es almacenada de manera segura por :link',
    'support' => 'Soporte',
    'contact_information' => 'Información de Contacto',
    '256_encryption' => 'Encripción de 256-Bit',
    'amount_due' => 'Importe a pagar',
    'billing_address' => 'Dirección de facturación',
    'billing_method' => 'Método de facturación',
    'order_overview' => 'Resumen de la orden',
    'match_address' => '*La dirección debe coincidir con la dirección asociada a la tarjeta de crédito.',
    'click_once' => '*Por favor haga clic en "PAGAR AHORA" sólo una vez - la transacción puede demorarse hasta un minuto en ser procesada.',
    'invoice_footer' => 'Pie de págia de la factura',
    'save_as_default_footer' => 'Guardar como el pie de página por defecto',
    'token_management' => 'Administración de Tokens',
    'tokens' => 'Tokens',
    'add_token' => 'Agregar Token',
    'show_deleted_tokens' => 'Mostrar los tokens eliminados',
    'deleted_token' => 'Token eliminado con éxito',
    'created_token' => 'Token creado con éxito',
    'updated_token' => 'Token actualizado con éxito',
    'edit_token' => 'Editar Token',
    'delete_token' => 'Eliminar Token',
    'token' => 'Token',
    'add_gateway' => 'Agregar Gateway',
    'delete_gateway' => 'Eliminar Gateway',
    'edit_gateway' => 'Editar Gateway',
    'updated_gateway' => 'Gateway actualizado con éxito',
    'created_gateway' => 'Gateway creado con éxito',
    'deleted_gateway' => 'Gateway eliminado con éxito',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Tarjeta de Crédito',
    'change_password' => 'Cambiar Contraseña',
    'current_password' => 'Contraseña Actual',
    'new_password' => 'Nueva Contraseña',
    'confirm_password' => 'Confirmar Contraseña',
    'password_error_incorrect' => 'La contraseña actual es incorrecta.',
    'password_error_invalid' => 'La nueva contraseña no es válida.',
    'updated_password' => 'Contraseña actualizada correctamente',
    'api_tokens' => 'API Tokens',
    'users_and_tokens' => 'Usuarios & Tokens',
    'account_login' => 'Iniciar Sesión',
    'recover_password' => 'Recuperar contraseña',
    'forgot_password' => 'Olvidó su contraseña?',
    'email_address' => 'Correo Electrónico',
    'lets_go' => 'Acceder',
    'password_recovery' => 'Recuperación de Contraseña',
    'send_email' => 'Enviar email',
    'set_password' => 'Asignar Contraseña',
    'converted' => 'Convertido',
    'email_approved' => 'Enviarme un correo cuando una cotización sea <b>aprobada</b>',
    'notification_quote_approved_subject' => 'Cotización :invoice fue aprobada por :client',
    'notification_quote_approved' => 'El cliente :client ha aprobado la cotización :invoice por el valor :amount.',
    'resend_confirmation' => 'Reenviar correo de confirmación',
    'confirmation_resent' => 'El correo de confirmación fue reenviado',
    'gateway_help_42' => ':link para registrarse en BitPay.<br/>Nota: use una llave del API legacy, no un token API.',
    'payment_type_credit_card' => 'Tarjeta de Crédito',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Base de Conocimiento',
    'partial' => 'Parcial/Depósito',
    'partial_remaining' => ':partial de :balance',
    'more_fields' => 'Más Campos',
    'less_fields' => 'Menos Campos',
    'client_name' => 'Nombre del Cliente',
    'pdf_settings' => 'Configuración de PDF',
    'product_settings' => 'Configuración del Producto',
    'auto_wrap' => 'Ajuste Automático de Línea',
    'duplicate_post' => 'Advertencia: la página anterior fue enviada dos veces. El segundo envío ha sido ignorado.',
    'view_documentation' => 'Ver Documentación',
    'app_title' => 'Facturación Open-Source Gratuita',
    'app_description' => 'Invoice Ninja es una solución open-source gratuita para manejar la facturación de tus clientes. Con Invoice Ninja, se pueden crear y enviar hermosas facturas desde cualquier dispositivo que tenga acceso a Internet. Tus clientes pueden imprimir tus facturas, descargarlas en formato PDF o inclusive pagarlas en linea desde esta misma plataforma',
    'rows' => 'filas',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdominio',
    'provide_name_or_email' => 'Por favor, ingrese un nombre o email',
    'charts_and_reports' => 'Gráficas y Reportes',
    'chart' => 'Gráfica',
    'report' => 'Reporte',
    'group_by' => 'Agrupar por',
    'paid' => 'Pagado',
    'enable_report' => 'Reportes',
    'enable_chart' => 'Gráficas',
    'totals' => 'Totales',
    'run' => 'Ejecutar',
    'export' => 'Exportar',
    'documentation' => 'Documentación',
    'zapier' => 'Zapier',
    'recurring' => 'Recurrente',
    'last_invoice_sent' => 'Ultima factura enviada en :date',
    'processed_updates' => 'Actualización completada con éxito',
    'tasks' => 'Tareas',
    'new_task' => 'Nueva Tarea',
    'start_time' => 'Tiempo de Inicio',
    'created_task' => 'Tarea creada con éxito',
    'updated_task' => 'Tarea actualizada con éxito',
    'edit_task' => 'Editar Tarea',
    'clone_task' => 'Clonar Tarea',
    'archive_task' => 'Archivar Tarea',
    'restore_task' => 'Restaurar Tarea',
    'delete_task' => 'Eliminar Tarea',
    'stop_task' => 'Detener Tarea',
    'time' => 'Tiempo',
    'start' => 'Iniciar',
    'stop' => 'Detener',
    'now' => 'Ahora',
    'timer' => 'Temporizador',
    'manual' => 'Manual',
    'date_and_time' => 'Fecha y Hora',
    'second' => 'Segundo',
    'seconds' => 'Segundos',
    'minute' => 'Minuto',
    'minutes' => 'Minutos',
    'hour' => 'Hora',
    'hours' => 'Horas',
    'task_details' => 'Detalles de la Tarea',
    'duration' => 'Duración',
    'time_log' => 'Registro de Tiempo',
    'end_time' => 'Tiempo Final',
    'end' => 'Fin',
    'invoiced' => 'Facturado',
    'logged' => 'Registrado',
    'running' => 'Ejecutando',
    'task_error_multiple_clients' => 'Las tareas no pueden pertenecer a diferentes clientes',
    'task_error_running' => 'Por favor primero detenga las tareas que se estén ejecutando',
    'task_error_invoiced' => 'Las tareas ya han sido facturadas',
    'restored_task' => 'Tarea restaurada con éxito',
    'archived_task' => 'Tarea archivada con éxito',
    'archived_tasks' => ':count tareas archivadas con éxito',
    'deleted_task' => 'Tarea eliminada con éxito',
    'deleted_tasks' => ':count tareas eliminadas con éxito',
    'create_task' => 'Crear Tarea',
    'stopped_task' => 'Tarea detenida con éxito',
    'invoice_task' => 'Tarea de Factura',
    'invoice_labels' => 'Etiquetas',
    'prefix' => 'Prefijo',
    'counter' => 'Contador',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link para registrarse con Dwolla.',
    'partial_value' => 'Debe ser mayor que cero y menor que el total',
    'more_actions' => 'Más Acciones',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Actualízate Ahora!',
    'pro_plan_feature1' => 'Crea Clientes Ilimitados',
    'pro_plan_feature2' => 'Accede a 10 hermosos diseños de factura',
    'pro_plan_feature3' => 'URLs Personalizadas - "SuMarca.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Remueve "Creado por Invoice Ninja"',
    'pro_plan_feature5' => 'Acceso Multi-usuario y seguimiento de actividades',
    'pro_plan_feature6' => 'Crea Cotizaciones y facturas Pro-forma',
    'pro_plan_feature7' => 'Personaliza los Títulos de los Campos y Numeración de las Facturas',
    'pro_plan_feature8' => 'Opción para adjuntarle documentos PDF a los correos dirigidos a los clientes',
    'resume' => 'Continuar',
    'break_duration' => 'Descanso',
    'edit_details' => 'Editar Detalles',
    'work' => 'Trabajo',
    'timezone_unset' => 'Por favor :link para configurar tu Uso Horario',
    'click_here' => 'haz clic aquí',
    'email_receipt' => 'Enviar por correo electrónico el recibo de pago al cliente',
    'created_payment_emailed_client' => 'Pago creado y enviado al cliente con éxito',
    'add_company' => 'Agregar Empresa',
    'untitled' => 'Sin Título',
    'new_company' => 'Nueva Empresa',
    'associated_accounts' => 'Cuentas conectadas con éxito',
    'unlinked_account' => 'Cuentas desconectadas con éxito',
    'login' => 'Iniciar Sesión',
    'or' => 'o',
    'email_error' => 'Hubo un problema enviando el correo',
    'confirm_recurring_timing' => 'Nota: los correos son enviados al inicio de la hora.',
    'confirm_recurring_timing_not_sent' => 'Nota: Las facturas son creadas al inicio de la hora.',
    'payment_terms_help' => 'Establecer <b>fecha de vencimiento de la factura</b> por defecto',
    'unlink_account' => 'Desconectar Cuenta',
    'unlink' => 'Desconectar',
    'show_address' => 'Actualizar Dirección',
    'show_address_help' => 'Requerir que el cliente indique su dirección de facturación',
    'update_address' => 'Actualizar Dirección',
    'update_address_help' => 'Actualiza la dirección del cliente con los detalles proporcionados',
    'times' => 'Tiempos',
    'set_now' => 'Asignar ahora',
    'dark_mode' => 'Modo Oscuro',
    'dark_mode_help' => 'Usar un fondo oscuro en la barra lateral',
    'add_to_invoice' => 'Agregar a cuenta :invoice',
    'create_new_invoice' => 'Crear Nueva Cuenta',
    'task_errors' => 'Por favor corrija cualquier tiempo que se sobreponga con otro',
    'from' => 'De',
    'to' => 'Para',
    'font_size' => 'Tamaño de Letra',
    'primary_color' => 'Color Primario',
    'secondary_color' => 'Color Secundario',
    'customize_design' => 'Personalizar Diseño',
    'content' => 'Contenido',
    'styles' => 'Estilos',
    'defaults' => 'Valores por Defecto',
    'margins' => 'Márgenes',
    'header' => 'Encabezado',
    'footer' => 'Pie de Página',
    'custom' => 'Personalizado',
    'invoice_to' => 'Factura para',
    'invoice_no' => 'Factura #',
    'quote_no' => 'Quote No.',
    'recent_payments' => 'Pagos Recientes',
    'outstanding' => 'Pendiente de Cobro',
    'manage_companies' => 'Gestionar Empresas',
    'total_revenue' => 'Ingresos Totales',
    'current_user' => 'Usuario Actual',
    'new_recurring_invoice' => 'Nueva Factura Recurrente',
    'recurring_invoice' => 'Factura Recurrente',
    'new_recurring_quote' => 'Nueva Cotización Recurrente',
    'recurring_quote' => 'Cotización Recurrente',
    'recurring_too_soon' => 'Es muy pronto para crear la siguiente factura recurrente, está programada para :date',
    'created_by_invoice' => 'Creado por :invoice',
    'primary_user' => 'Usuario Principal',
    'help' => 'Ayuda',
    'customize_help' => '<p>Nosotros usamos :pdfmake_link para definir los diseños de factura de manera declarativa. El :playground_link provides de pdfmake es una excelente manera de ver a la librería en acción.</p>
                        <p>Si necesitas ayuda con cómo hacer algo,haz una pregunta en nuestro :forum_link incluyendo el diseño que estás usando.</p>',
    'playground' => 'playground',
    'support_forum' => 'foro de soporte',
    'invoice_due_date' => 'Fecha de Vencimiento',
    'quote_due_date' => 'Válida Hasta',
    'valid_until' => 'Válida Hasta',
    'reset_terms' => 'Reiniciar términos',
    'reset_footer' => 'Reiniciar pie de página',
    'invoice_sent' => ':count factura enviada',
    'invoices_sent' => ':count facturas enviadas',
    'status_draft' => 'Borrador',
    'status_sent' => 'Enviado',
    'status_viewed' => 'Visto',
    'status_partial' => 'Parcial',
    'status_paid' => 'Pagado',
    'status_unpaid' => 'Sin pagar',
    'status_all' => 'Todas',
    'show_line_item_tax' => ' Mostrar <b>impuestos por cada item</b> en línea.',
    'iframe_url' => 'Sitio Web',
    'iframe_url_help1' => 'Copia el siguiente código en una página de tu sitio web.',
    'iframe_url_help2' => 'Puedes probar esta funcionalidad haciendo clic en \'Ver como el destinitario\' de una factura.',
    'auto_bill' => 'Cobro Automático',
    'military_time' => 'Tiempo 24 Horas',
    'last_sent' => 'Último Enviado',
    'reminder_emails' => 'Correos de Recordatorio',
    'quote_reminder_emails' => 'Correos de Recordatorio de Cotizaciones',
    'templates_and_reminders' => 'Plantillas & Recordatorios',
    'subject' => 'Asunto',
    'body' => 'Mensaje',
    'first_reminder' => 'Primer Recordatorio',
    'second_reminder' => 'Segundo Recordatorio',
    'third_reminder' => 'Tercer Recordatorio',
    'num_days_reminder' => 'Días después de la fecha de vencimiento',
    'reminder_subject' => 'Recordatorio: Factura :invoice de :account',
    'reset' => 'Reiniciar',
    'invoice_not_found' => 'La factura solicitada no está disponible',
    'referral_program' => 'Programa de Referidos',
    'referral_code' => 'Código de Referidos',
    'last_sent_on' => 'último enviado en :date',
    'page_expire' => 'Esta página expirará pronto, :click_here para que siga funcionando',
    'upcoming_quotes' => 'Próximas Cotizaciones',
    'expired_quotes' => 'Cotizaciones Vencidas',
    'sign_up_using' => 'Ingrese usando',
    'invalid_credentials' => 'Estas credenciales no concuerdan con nuestros registros',
    'show_all_options' => 'Mostrar todas las opciones',
    'user_details' => 'Detalles de Usuario',
    'oneclick_login' => 'Cuenta conectada',
    'disable' => 'Deshabilitado',
    'invoice_quote_number' => 'Números de Cotización y Factura',
    'invoice_charges' => 'Cargos de Factura',
    'notification_invoice_bounced' => 'No nos fue posible entregar la Factura :invoice a :contact.',
    'notification_invoice_bounced_subject' => 'No fue posible entregar la Factura :invoice',
    'notification_quote_bounced' => 'No nos fue posible entregar la Cotización :invoice a :contact.',
    'notification_quote_bounced_subject' => 'No nos fue posible entregar la Cotización :invoice',
    'custom_invoice_link' => 'Link Personalizado de Factura',
    'total_invoiced' => 'Total Facturado',
    'open_balance' => 'Saldo Abierto',
    'verify_email' => 'Para verificar su cuenta de correo por favor visite el link en el correo de confirmación de tu cuenta.',
    'basic_settings' => 'Configuración Básica',
    'pro' => 'Pro',
    'gateways' => 'Pasarelas de Pago',
    'next_send_on' => 'Enviar Siguiente: :date',
    'no_longer_running' => 'La ejecución de esta factura no está programada',
    'general_settings' => 'Configuración General',
    'customize' => 'Personalizar',
    'oneclick_login_help' => 'Conecta una cuenta para ingresar sin contraseña',
    'referral_code_help' => 'Gana dinero compartiendo nuestra app online',
    'enable_with_stripe' => 'Habilitado | Requiere Stripe',
    'tax_settings' => 'Configuración de Impuestos',
    'create_tax_rate' => 'Agregar Tasa de Impuesto',
    'updated_tax_rate' => 'Tasa de impuesto actualizada con éxito',
    'created_tax_rate' => 'Tasa de impuesto creada con éxito',
    'edit_tax_rate' => 'Editar tasa de impuesto',
    'archive_tax_rate' => 'Archivar tasa de impuesto',
    'archived_tax_rate' => 'Tasa de impuesto archivada con éxito',
    'default_tax_rate_id' => 'Tasa de Impuesto por Defecto',
    'tax_rate' => 'Tasa de Impuesto',
    'recurring_hour' => 'Hora Recurrente',
    'pattern' => 'Patrón',
    'pattern_help_title' => 'Ayuda de Patrón',
    'pattern_help_1' => 'Crear números personalizados, especificando un patrón',
    'pattern_help_2' => 'Variables disponibles:',
    'pattern_help_3' => 'Por ejemplo, :example sería convertido a :value',
    'see_options' => 'Ver Opciones',
    'invoice_counter' => 'Contador de Facturas',
    'quote_counter' => 'Contador de Cotizaciones',
    'type' => 'Tipo',
    'activity_1' => ':user creó el cliente :client',
    'activity_2' => ':user archivó el cliente :client',
    'activity_3' => ':user eliminó el cliente :client',
    'activity_4' => ':user creó la factura :invoice',
    'activity_5' => ':user actualizó la factura :invoice',
    'activity_6' => ':user envió por correo electrónico la factura :invoice para el cliente :client a :contact ',
    'activity_7' => ':contact vió la factura :invoice del cliente :client',
    'activity_8' => ':user archivó la factura :invoice',
    'activity_9' => ':user eliminó la factura :invoice',
    'activity_10' => ':contact ingresó el pago :payment por el valor :payment_amount en la factura :invoice del cliente :client',
    'activity_11' => ':user actualizó el pago :payment',
    'activity_12' => ':user archivó el pago :payment',
    'activity_13' => ':user eliminó el pago :payment',
    'activity_14' => ':user ingresó :credit créditos',
    'activity_15' => ':user actualizó :credit créditos',
    'activity_16' => ':user archivó :credit créditos',
    'activity_17' => ':user eliminó :credit créditos',
    'activity_18' => ':user creó la cotización :quote',
    'activity_19' => ':user actualizó la cotización :quote',
    'activity_20' => ':user envió por correo electrónico la cotización :quote a :contact',
    'activity_21' => ':contact vió la cotización :quote',
    'activity_22' => ':user archivó la cotización :quote',
    'activity_23' => ':user eliminó la cotización :quote',
    'activity_24' => ':user restauró la cotización :quote',
    'activity_25' => ':user restauró factura :invoice',
    'activity_26' => ':user restauró el cliente :client',
    'activity_27' => ':user restauró el pago :payment',
    'activity_28' => ':user restauró :credit créditos',
    'activity_29' => ':contact aprovó la cotización :quote para el cliente :client',
    'activity_30' => ':user creó al vendedor :vendor',
    'activity_31' => ':user archivó al vendedor :vendor',
    'activity_32' => ':user eliminó al vendedor :vendor',
    'activity_33' => ':user restauró al vendedor :vendor',
    'activity_34' => ':user creó expense :expense',
    'activity_35' => ':user archivó el gasto :expense',
    'activity_36' => ':user eliminó el gasto :expense',
    'activity_37' => ':user restauró el gasto :expense',
    'activity_42' => ':user creó la tarea :task',
    'activity_43' => ':user actualizó la tarea :task',
    'activity_44' => ':user archivó la tarea :task',
    'activity_45' => ':user eliminó la tarea :task',
    'activity_46' => ':user restauró la tarea :task',
    'activity_47' => ':user actrulizó el gasto :expense',
    'activity_48' => ':user actualizó el ticket :ticket',
    'activity_49' => ':user cerró el ticket :ticket',
    'activity_50' => ':user fusionó el ticket :ticket',
    'activity_51' => ':user dividió el ticket :ticket',
    'activity_52' => ':contact abrió el ticket :ticket',
    'activity_53' => ':contact volvió a abrir el ticket :ticket',
    'activity_54' => ':user volvió a abrir el ticket :ticket',
    'activity_55' => ':contact respondió el ticket :ticket',
    'activity_56' => ':user vió el ticket :ticket',

    'payment' => 'pago',
    'system' => 'Sistema',
    'signature' => 'Firma del correo',
    'default_messages' => 'Mensajes por defecto',
    'quote_terms' => 'Terminos de Cotización',
    'default_quote_terms' => 'Terminos de Cotización por defecto',
    'default_invoice_terms' => 'Configurar términos de factura por defecto',
    'default_invoice_footer' => 'Asignar pie de página por defecto para la factura',
    'quote_footer' => 'Pie de la Cotización',
    'free' => 'Gratis',
    'quote_is_approved' => 'Aprobado exitosamente ',
    'apply_credit' => 'Aplicar Crédito',
    'system_settings' => 'Configuración del Sistema',
    'archive_token' => 'Archivar Token',
    'archived_token' => 'Token archivado',
    'archive_user' => 'Archivar Usuario',
    'archived_user' => 'Usuario archivado',
    'archive_account_gateway' => 'Eliminar Pasarela de Pago',
    'archived_account_gateway' => 'Pasarela archivada',
    'archive_recurring_invoice' => 'Archivar Factura periódica',
    'archived_recurring_invoice' => 'Factura periódica archivada',
    'delete_recurring_invoice' => 'Borrar Factura periódica',
    'deleted_recurring_invoice' => 'Factura periódica borrada',
    'restore_recurring_invoice' => 'Restaurar Factura periódica ',
    'restored_recurring_invoice' => 'Factura periódica restaurada',
    'archive_recurring_quote' => 'Archivar Cotización Recurrente',
    'archived_recurring_quote' => 'Cotización recurrente archivada con éxito',
    'delete_recurring_quote' => 'Eliminar Cotización Recurrente',
    'deleted_recurring_quote' => 'Cotización recurrente eliminada con éxito',
    'restore_recurring_quote' => 'Restaurar Cotización Recurrente',
    'restored_recurring_quote' => 'Cotización recurrente restaurada con éxito',
    'archived' => 'Archivado',
    'untitled_account' => 'Empresa sin Nombre',
    'before' => 'Antes',
    'after' => 'Después',
    'reset_terms_help' => 'Reestablecer los términos de cuenta predeterminados',
    'reset_footer_help' => 'Reestablecer el pie predeterminado',
    'export_data' => 'Exportar',
    'user' => 'Usuario',
    'country' => 'País',
    'include' => 'Incluir',
    'logo_too_large' => 'El logo es :size, para un buen rendimiento del PDF, sugerimos cargar una imagen de menos de 200KB',
    'import_freshbooks' => 'Importar desde FreshBooks',
    'import_data' => 'Importar datos',
    'source' => 'Origen',
    'csv' => 'CSV',
    'client_file' => 'Archivo de Clientes',
    'invoice_file' => 'Archivo de Facturas',
    'task_file' => 'Archivo de Tareas',
    'no_mapper' => 'Mapeo no válido para el Archivo',
    'invalid_csv_header' => 'Cabecera CSV no Válida',
    'client_portal' => 'Portal de Cliente',
    'admin' => 'Admin.',
    'disabled' => 'Deshabilitado',
    'show_archived_users' => 'Mostrar usuarios archivados',
    'notes' => 'Notas',
    'invoice_will_create' => 'la factura será creada',
    'invoices_will_create' => 'facturas seran creadas',
    'failed_to_import' => 'Los siguientes registros fallaron al importar',
    'publishable_key' => 'Clave pública',
    'secret_key' => 'Clave Privada',
    'missing_publishable_key' => 'Establece tu clave pública de Stripe para mejorar el proceso de checkout',
    'email_design' => 'Diseño de Correo',
    'due_by' => 'Pagado en :date',
    'enable_email_markup' => 'Habilitar Markup',
    'enable_email_markup_help' => 'Haga que sea fácil para sus clientes que paguen mediante la adición de marcas "schema.org" a sus correos electrónicos.',
    'template_help_title' => 'Ayuda',
    'template_help_1' => 'Variables disponibles:',
    'email_design_id' => 'Estilo de Correo',
    'email_design_help' => 'Haga que sus mensajes de correo electrónico tengan un aspecto más profesional con diseños HTML',
    'plain' => 'Plano',
    'light' => 'Claro',
    'dark' => 'Oscuro',
    'industry_help' => 'Usado para proporcionar comparaciones de las medias de las empresas de tamaño y industria similar.',
    'subdomain_help' => 'Asigne el suubdominio o mostrar la factura en su propio sitio web.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Especifique un prefijo o utilice un patrón a medida para establecer dinámicamente el número de factura.',
    'quote_number_help' => 'Especifique un prefijo o utilice un patrón a medida para establecer dinámicamente el número de presupuesto.',
    'custom_client_fields_helps' => 'Agregue un campo al crear un cliente y, opcionalmente, muestre la etiqueta y el valor en el PDF.',
    'custom_account_fields_helps' => 'Añadir una etiqueta y valor a la sección de detalles de la empresa del PDF.',
    'custom_invoice_fields_helps' => 'Agregue un campo al crear una factura y, opcionalmente, muestre la etiqueta y el valor en el PDF.',
    'custom_invoice_charges_helps' => 'gregar una entrada de texto a la pagina de crear/editar factura y mostrar la carga en los subtotales de la factura.',
    'token_expired' => 'Token de validación ha caducado. Por favor, vuelva a intentarlo.',
    'invoice_link' => 'Enlace a Factura',
    'button_confirmation_message' => 'Pulse aqui para confirmar su dirección de correo.',
    'confirm' => 'Confirmar',
    'email_preferences' => 'Preferencias de Correo',
    'created_invoices' => ':count factura(s) creada(s) correctamente',
    'next_invoice_number' => 'El próximo número de factura es :number.',
    'next_quote_number' => 'El próximo número de presupuesto es :number.',
    'days_before' => 'días antes de',
    'days_after' => 'días después de',
    'field_due_date' => 'fecha de pago',
    'field_invoice_date' => 'fecha de factura',
    'schedule' => 'Programar',
    'email_designs' => 'Diseños de correo',
    'assigned_when_sent' => 'Asignado al enviar',
    'white_label_purchase_link' => 'Comprar licencia de marca blanca',
    'expense' => 'Gasto',
    'expenses' => 'Gastos',
    'new_expense' => 'Ingrese el Gasto',
    'enter_expense' => 'Introducir Gasto',
    'vendors' => 'Proveedores',
    'new_vendor' => 'Nuevo Proveedor',
    'payment_terms_net' => 'Net',
    'vendor' => 'Proveedor',
    'edit_vendor' => 'Editar Proveedor',
    'archive_vendor' => 'Archivar Proveedor',
    'delete_vendor' => 'Borrar Proveedor',
    'view_vendor' => 'Ver Proveedor',
    'deleted_expense' => 'Gasto borrado correctamente',
    'archived_expense' => 'Gasto archivado correctamente',
    'deleted_expenses' => 'Gastos borrados correctamente',
    'archived_expenses' => 'Gastos archivados correctamente',
    'expense_amount' => 'Importe del Gasto',
    'expense_balance' => 'Saldo del Gasto',
    'expense_date' => 'Fecha del Gasto',
    'expense_should_be_invoiced' => '¿Este gasto debe ser facturado?',
    'public_notes' => 'Notas',
    'invoice_amount' => 'Importe de Factura',
    'exchange_rate' => 'Tipo de Cambio',
    'yes' => 'Si',
    'no' => 'No',
    'should_be_invoiced' => 'Debe ser Facturado',
    'view_expense' => 'Ver gasto # :expense',
    'edit_expense' => 'Editar Gasto',
    'archive_expense' => 'Archivar Gasto',
    'delete_expense' => 'Borrar Gasto',
    'view_expense_num' => 'Gasto # :expense',
    'updated_expense' => 'Gasto actualizado correctamente',
    'created_expense' => 'Gasto creado correctamente',
    'enter_expense' => 'Introducir Gasto',
    'view' => 'Ver',
    'restore_expense' => 'Restaurar Gasto',
    'invoice_expense' => 'Facturar Gasto',
    'expense_error_multiple_clients' => 'Los gastos no pertenecen a diferentes clientes',
    'expense_error_invoiced' => 'El gasto ya ha sido Facturado',
    'convert_currency' => 'Convertir moneda',
    'num_days' => 'Número de Días',
    'create_payment_term' => 'Crear Términos de Pago',
    'edit_payment_terms' => 'Editar los Términos de Pago',
    'edit_payment_term' => 'Editar el Términos de Pago',
    'archive_payment_term' => 'Archivar Términos de Pago',
    'recurring_due_dates' => 'Fecha de Vencimiento de Factura Recurrente',
    'recurring_due_date_help' => '<p>Define automáticamente una fecha de vencimiento de la factura.</p>
        <p>Facturas en un ciclo mensual o anual preparadas para vencer el día que se crearon o antes, vencerán al siguiente mes. Facturas preparadas para vencer el 29 o el 30, en los meses que no tienen ese día, vencerán el último día del mes</p>
        <p>(Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.)</p>
        <p>Facturas en un ciclo semanal preparadas para vencer el día de la semana que se crearon, vencerán a la siguiente semana.</p>
        <p>(Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.)</p>
        <p>Por ejemplo:</p>
        <ul>
          <li>Hoy es día 15, la fecha de vencimiento es el día 1 de cada mes. La fecha de vencimiento deberá ser el día 1 del siguiente mes.</li>
          <li>Hoy es día 15, la fecha de vencimiento es el último día de cada mes. La fecha de vencimiento deberá ser el último día de este mes.</li>
          <li>Hoy es día 15, la fecha de vencimiento es el día 15 de cada mes. La fecha de vencimiento deberá ser el día 15 del <strong>siguiente</strong> mes.</li>
          <li>Hoy es Viernes, la fecha de vencimiento es Viernes. La fecha de vencimiento deberá ser el siguiente Viernes, no hoy.</li>
        </ul>',
    'due' => 'Vencimiento',
    'next_due_on' => 'Próximo Vencimiento: :date',
    'use_client_terms' => 'Utilizar términos del cliente',
    'day_of_month' => ':ordinal día del mes',
    'last_day_of_month' => 'Último día del mes',
    'day_of_week_after' => ':ordinal :day despues',
    'sunday' => 'Domingo',
    'monday' => 'Lunes',
    'tuesday' => 'Martes',
    'wednesday' => 'Miércoles',
    'thursday' => 'Jueves',
    'friday' => 'Viernes',
    'saturday' => 'Sábado',
    'header_font_id' => 'Tipo de letra de la cabecera',
    'body_font_id' => 'Tipo de letra del cuerpo',
    'color_font_help' => 'Nota: el color primario y las fuentes también se utilizan en el portal del cliente y los diseños de correo electrónico personalizados.',
    'live_preview' => 'Live Preview',
    'invalid_mail_config' => 'Imposible enviar el correo, por favor, comprobar que la configuración de correo es correcta.',
    'invoice_message_button' => 'Para ver su factura con importe  :amount, pulse el siguiente botón.',
    'quote_message_button' => 'Para ver su presupuesto con importe :amount, pulse el siguiente botón.',
    'payment_message_button' => 'Gracias por su pago de :amount.',
    'payment_type_direct_debit' => 'Débito Automático',
    'bank_accounts' => 'Cuentas Bancarias',
    'add_bank_account' => 'Añadir Cuenta Bancaria',
    'setup_account' => 'Configurar Cuenta',
    'import_expenses' => 'Importar Gastos',
    'bank_id' => 'banco',
    'integration_type' => 'Tipo de Integración',
    'updated_bank_account' => 'Cuenta Bancaria actualizada correctamente',
    'edit_bank_account' => 'Editar Cuenta Bancaria',
    'archive_bank_account' => 'Archivar Cuenta Bancaria',
    'archived_bank_account' => 'Cuenta Bancaria archivada correctamente',
    'created_bank_account' => 'Cuenta Bancaria creada correctamente',
    'validate_bank_account' => 'Validar Cuenta Bancaria',
    'bank_password_help' => 'Nota: su contraseña es transmitida de manera secura y nunca almacenada en nuestros servidores.',
    'bank_password_warning' => 'Advertencia: su contraseña puede ser transmitida en texto plano, considere habilitar HTTPS.',
    'username' => 'Usuario',
    'account_number' => 'Número de Cuenta',
    'account_name' => 'Nombre de Cuenta',
    'bank_account_error' => 'No fue posible obtener los detalles de la cuenta, por favor chequea tus credenciales.',
    'status_approved' => 'Aprobado',
    'quote_settings' => 'Configuración de Presupuestos',
    'auto_convert_quote' => 'Auto Convertir',
    'auto_convert_quote_help' => 'Convierte un presupuesto en factura automaticamente cuando los aprueba el cliente.',
    'validate' => 'Validar',
    'info' => 'Info',
    'imported_expenses' => ' :count_vendors proveedor(es) y :count_expenses gasto(s) importados correctamente',
    'iframe_url_help3' => 'Nota: Si piensas aceptar tarjetas de crédito recomendamos tener habilitado HTTPS.',
    'expense_error_multiple_currencies' => 'Los gastos no pueden tener distintas divisas.',
    'expense_error_mismatch_currencies' => 'La divisa del cliente no coincide con la divisa del gasto.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Encabezado/Pie',
    'first_page' => 'Primera página',
    'all_pages' => 'Todas las páginas',
    'last_page' => 'Última página',
    'all_pages_header' => 'Mostrar encabezado',
    'all_pages_footer' => 'Mostrar pie',
    'invoice_currency' => 'Divisa de la Factura',
    'enable_https' => 'We strongly recommend using HTTPS to accept credit card details online.',
    'quote_issued_to' => 'Cotización emitida para',
    'show_currency_code' => 'Código de Divisa',
    'free_year_message' => 'Su cuenta ha sido actualizada al plan pro por un año, sin ningún costo.',
    'trial_message' => 'Your account will receive a free two week trial of our pro plan.',
    'trial_footer' => 'Su prueba gratuita del plan pro tiene :count días más, :link para actualizar ahora.',
    'trial_footer_last_day' => 'Este es el último día de su prueba gratuita del plan pro, :link para actualizar ahora.',
    'trial_call_to_action' => 'Start Free Trial',
    'trial_success' => 'Successfully enabled two week free pro plan trial',
    'overdue' => 'Overdue',


    'white_label_text' => 'Purchase a ONE YEAR white label license for $:price to remove the Invoice Ninja branding from the invoice and client portal.',
    'user_email_footer' => 'Para ajustar la configuración de las notificaciones de tu correo, visita :link',
    'reset_password_footer' => 'Si no has solicitado un cambio de contraseña, por favor contactate con nosostros: :email',
    'limit_users' => 'Lo sentimos, esta acción excederá el límite de :limit usarios',
    'more_designs_self_host_header' => 'Adquiera 6 diseños adicionales de facturas por solo $:price',
    'old_browser' => 'Por favor usa un :link',
    'newer_browser' => 'nuevo navegador',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Conecta una cuenta bancaria para importar gastos automáticamente y crear vendedores. soporta American Express y :link.',
    'us_banks' => '400+ bancos de Estados Unidos',

    'pro_plan_remove_logo' => ':link haz click para eliminar el logo de Invoice Ninja',
    'pro_plan_remove_logo_link' => 'Haz clic aquí',
    'invitation_status_sent' => 'Enviado',
    'invitation_status_opened' => 'Abierto',
    'invitation_status_viewed' => 'Visto',
    'email_error_inactive_client' => 'No se pueden enviar correos a Clientes inactivos',
    'email_error_inactive_contact' => 'No se pueden enviar correos a Contactos inactivos',
    'email_error_inactive_invoice' => 'No se pueden enviar correos de Facturas inactivas',
    'email_error_inactive_proposal' => 'No se pueden enviar emails a propuestas inactivas',
    'email_error_user_unregistered' => 'Por favor registre su cuenta para enviar correos',
    'email_error_user_unconfirmed' => 'Por favor confirme su cuenta para enviar correos',
    'email_error_invalid_contact_email' => 'Correo de contacto no válido',

    'navigation' => 'Navegación',
    'list_invoices' => 'Listar Facturas',
    'list_clients' => 'Listar Clientes',
    'list_quotes' => 'Listar Cotizaciones',
    'list_tasks' => 'Listar Tareas',
    'list_expenses' => 'Listar Gastos',
    'list_recurring_invoices' => 'Listar Facturas Recurrentes',
    'list_payments' => 'Listar Pagos',
    'list_credits' => 'Listar Créditos',
    'tax_name' => 'Nombre de Impuesto',
    'report_settings' => 'Configuración de Reportes',
    'search_hotkey' => 'Atajo es /',

    'new_user' => 'Nuevo Usuario',
    'new_product' => 'Nuevo Producto',
    'new_tax_rate' => 'Nueva Tasa de Impuesto',
    'invoiced_amount' => 'Importe Facturado',
    'invoice_item_fields' => 'Campos de Ítem de Factura',
    'custom_invoice_item_fields_help' => 'Agregar un campo al crear un ítem de factura y mostrar la etiqueta y valor en el PDF.',
    'recurring_invoice_number' => 'Número Recurrente',
    'recurring_invoice_number_prefix_help' => 'Especifica un prefijo para ser agregado al número de las facturas recurrentes.',

    // Client Passwords
    'enable_portal_password' => 'Proteger Facturas con Contraseña',
    'enable_portal_password_help' => 'Permite establecer una contraseña para cada contacto. Si una contraseña es establecida, se le será solicitada al contacto para acceder a sus facturas.',
    'send_portal_password' => 'Generar Automáticamente ',
    'send_portal_password_help' => 'Si no se establece una contraseña, será generada automáticamente con la primer factura.',

    'expired' => 'Vencida',
    'invalid_card_number' => 'El número de tarjeta de crédito no es válido.',
    'invalid_expiry' => 'La fecha de vencimiento no es válida.',
    'invalid_cvv' => 'El CVV no es válido.',
    'cost' => 'Costo',
    'create_invoice_for_sample' => 'Nota: cree una factura para previsualizarla aquí.',

    // User Permissions
    'owner' => 'Propietario',
    'administrator' => 'Administrador',
    'administrator_help' => 'Permitir que administre usuarios, cambie configuraciones y modifique cualquier registro',
    'user_create_all' => 'Crear clientes, facturas, etc.',
    'user_view_all' => 'Ver todos los clientes, facturas, etc.',
    'user_edit_all' => 'Editar todos los clientes, facturas, etc.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Recuperar Proveedor',
    'restored_vendor' => 'Proveedor recuperado con éxito',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'View Payment',

    'january' => 'Enero',
    'february' => 'Febrero',
    'march' => 'Marzo',
    'april' => 'Abril',
    'may' => 'Mayo',
    'june' => 'Junio',
    'july' => 'Julio',
    'august' => 'Agosto',
    'september' => 'Septiembre',
    'october' => 'Octubre',
    'november' => 'Noviembre',
    'december' => 'Diciembre',

    // Documents
    'documents_header' => 'Documentos:',
    'email_documents_header' => 'Documentos:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Documentos de Cotización',
    'invoice_documents' => 'Documentos de Factura',
    'expense_documents' => 'Documentos de Gasto',
    'invoice_embed_documents' => 'Embed Documents',
    'invoice_embed_documents_help' => 'Include attached images in the invoice.',
    'document_email_attachment' => 'Attach Documents',
    'ubl_email_attachment' => 'Adjuntar UBL',
    'download_documents' => 'Download Documents (:size)',
    'documents_from_expenses' => 'From Expenses:',
    'dropzone_default_message' => 'Drop files or click to upload',
    'dropzone_default_message_disabled' => 'Subidas de archivos deshabilitados',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'You can\'t upload files of this type.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Cancel upload',
    'dropzone_cancel_upload_confirmation' => 'Are you sure you want to cancel this upload?',
    'dropzone_remove_file' => 'Remove file',
    'documents' => 'Documents',
    'document_date' => 'Document Date',
    'document_size' => 'Size',

    'enable_client_portal' => 'Dashboard',
    'enable_client_portal_help' => 'Show/hide the dashboard page in the client portal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Show/hide the dashboard page in the client portal.',

    // Plans
    'account_management' => 'Account Management',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Never',
    'plan_free' => 'Free',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Mensual',
    'plan_term_yearly' => 'Yearly',
    'plan_term_month' => 'Mes',
    'plan_term_year' => 'Year',
    'plan_price_monthly' => '$:price/Month',
    'plan_price_yearly' => '$:price/Year',
    'updated_plan' => 'Updated plan settings',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Live Preview',
    'page_size' => 'Page Size',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'Listar Proveedores',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'The Enterprise plan adds support for multiple users and file attachments, :link to see the full list of features.',
    'return_to_app' => 'Regresar a la App',


    // Payment updates
    'refund_payment' => 'Refund Payment',
    'refund_max' => 'Max:',
    'refund' => 'Refund',
    'are_you_sure_refund' => 'Refund selected payments?',
    'status_pending' => 'Pending',
    'status_completed' => 'Completed',
    'status_failed' => 'Failed',
    'status_partially_refunded' => 'Partially Refunded',
    'status_partially_refunded_amount' => ':amount Refunded',
    'status_refunded' => 'Refunded',
    'status_voided' => 'Cancelled',
    'refunded_payment' => 'Refunded Payment',
    'activity_39' => ':usaer canceló :payment_amount pago :payment',
    'activity_40' => ':user reembolsó :adjustment de un pago de :payment_amount :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Unknown',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Aceptar transferencias bancarias de Estados Unidos',
    'stripe_ach_help' => 'El soporte ACH también debe ser habilitado en :link.',
    'ach_disabled' => 'Another gateway is already configured for direct debit.',

    'plaid' => 'Plaid',
    'client_id' => 'Client Id',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'cuando se te entrega una llave de prueba de Stripe, se usará el ambiente de desarrollo de Plaid (tartan). ',
    'other_providers' => 'Other Providers',
    'country_not_supported' => 'That country is not supported.',
    'invalid_routing_number' => 'The routing number is not valid.',
    'invalid_account_number' => 'The account number is not valid.',
    'account_number_mismatch' => 'The account numbers do not match.',
    'missing_account_holder_type' => 'Por favor seleccione una cuenta de empresa o persona.',
    'missing_account_holder_name' => 'Please enter the account holder\'s name.',
    'routing_number' => 'Routing Number',
    'confirm_account_number' => 'Confirm Account Number',
    'individual_account' => 'Individual Account',
    'company_account' => 'Cuenta de la Empresa',
    'account_holder_name' => 'Account Holder Name',
    'add_account' => 'Add Account',
    'payment_methods' => 'Payment Methods',
    'complete_verification' => 'Complete Verification',
    'verification_amount1' => 'Amount 1',
    'verification_amount2' => 'Amount 2',
    'payment_method_verified' => 'Verification completed successfully',
    'verification_failed' => 'Verification Failed',
    'remove_payment_method' => 'Remove Payment Method',
    'confirm_remove_payment_method' => 'Are you sure you want to remove this payment method?',
    'remove' => 'Remove',
    'payment_method_removed' => 'Removed payment method.',
    'bank_account_verification_help' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement. Please enter the amounts below.',
    'bank_account_verification_next_steps' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement.
        Once you have the amounts, come back to this payment methods page and click "Complete Verification" next to the account.',
    'unknown_bank' => 'Unknown Bank',
    'ach_verification_delay_help' => 'You will be able to use the account after completing verification. Verification usually takes 1-2 business days.',
    'add_credit_card' => 'Add Credit Card',
    'payment_method_added' => 'Added payment method.',
    'use_for_auto_bill' => 'Use For Autobill',
    'used_for_auto_bill' => 'Autobill Payment Method',
    'payment_method_set_as_default' => 'Set Autobill payment method.',
    'activity_41' => ':payment_amount payment (:payment) failed',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'You must :link.',
    'stripe_webhook_help_link_text' => 'add this URL as an endpoint at Stripe',
    'gocardless_webhook_help_link_text' => 'agrega esta URL como endpoint en GoCardless',
    'payment_method_error' => 'There was an error adding your payment methd. Please try again later.',
    'notification_invoice_payment_failed_subject' => 'Payment failed for Invoice :invoice',
    'notification_invoice_payment_failed' => 'A payment made by client :client towards Invoice :invoice failed. The payment has been marked as failed and :amount has been added to the client\'s balance.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Your bank account at :bank',
    'add_payment_method' => 'Add Payment Method',
    'account_holder_type' => 'Account Holder Type',
    'ach_authorization' => 'Autorizo ​​a :company a usar mi cuenta bancaria para pagos futuros y, si es necesario, acreditar electrónicamente mi cuenta para corregir débitos erróneos. Entiendo que puedo cancelar esta autorización en cualquier momento eliminando el método de pago o poniéndome en contacto con :email.',
    'ach_authorization_required' => 'You must consent to ACH transactions.',
    'off' => 'Off',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Always',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Manage Auto-bill',
    'enabled' => 'Enabled',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'The PayPal gateway is processing PayPal payments',
    'braintree_paypal_help' => 'You must also :link.',
    'braintree_paypal_help_link_text' => 'link PayPal to your BrainTree account',
    'token_billing_braintree_paypal' => 'Save payment details',
    'add_paypal_account' => 'Add PayPal Account',


    'no_payment_method_specified' => 'No payment method specified',
    'chart_type' => 'Chart Type',
    'format' => 'Format',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed to parse OFX file',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up with WePay',
    'use_another_provider' => 'Use another provider',
    'company_name' => 'Nombre de Empresa',
    'wepay_company_name_help' => 'This will appear on client\'s credit card statements.',
    'wepay_description_help' => 'The purpose of this account.',
    'wepay_tos_agree' => 'I agree to the :link.',
    'wepay_tos_link_text' => 'WePay Terms of Service',
    'resend_confirmation_email' => 'Reenviar correo de confirmación',
    'manage_account' => 'Manage Account',
    'action_required' => 'Action Required',
    'finish_setup' => 'Finish Setup',
    'created_wepay_confirmation_required' => 'Please check your email and confirm your email address with WePay.',
    'switch_to_wepay' => 'Switch to WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Restore Gateway',
    'restored_account_gateway' => 'Successfully restored gateway',
    'united_states' => 'United States',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accept Debit Cards',
    'debit_cards' => 'Debit Cards',

    'warn_start_date_changed' => 'The next invoice will be sent on the new start date.',
    'warn_start_date_changed_not_sent' => 'La siguiente factura será creada con la nueva fecha de inicio.',
    'original_start_date' => 'Original start date',
    'new_start_date' => 'New start date',
    'security' => 'Security',
    'see_whats_new' => 'See what\'s new in v:version',
    'wait_for_upload' => 'Please wait for the document upload to complete.',
    'upgrade_for_permissions' => 'Upgrade to our Enterprise plan to enable permissions.',
    'enable_second_tax_rate' => 'Enable specifying a <b>second tax rate</b>',
    'payment_file' => 'Payment File',
    'expense_file' => 'Expense File',
    'product_file' => 'Archivo de Productos',
    'import_products' => 'Importar productos',
    'products_will_create' => 'productos serán creados',
    'product_key' => 'Producto',
    'created_products' => 'Creación exitosa/actualización :cuenta producto(s)',
    'export_help' => 'Use JSON si planea importar la información en Invoice Ninja.<br/>El archivo incluye clientes, productos, facturas, cotizaciones y pagos.',
    'selfhost_export_help' => '<br/>Nosotros recomendamos usar mysqldump para realizar una copia de seguridad completa.',
    'JSON_file' => 'JSON File',

    'view_dashboard' => 'View Dashboard',
    'client_session_expired' => 'Session Expired',
    'client_session_expired_message' => 'Your session has expired. Please click the link in your email again.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bank account',
    'auto_bill_payment_method_credit_card' => 'credit card',
    'auto_bill_payment_method_paypal' => 'PayPal account',
    'auto_bill_notification_placeholder' => 'This invoice will automatically be billed to your credit card on file on the due date.',
    'payment_settings' => 'Payment Settings',

    'on_send_date' => 'On send date',
    'on_due_date' => 'On due date',
    'auto_bill_ach_date_help' => 'ACH siempre facturará automáticamente en la fecha de vencimiento.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Bank Account',
    'payment_processed_through_wepay' => 'ACH payments will be processed using WePay.',
    'wepay_payment_tos_agree' => 'I agree to the WePay :terms and :privacy_policy.',
    'privacy_policy' => 'Privacy Policy',
    'wepay_payment_tos_agree_required' => 'You must agree to the WePay Terms of Service and Privacy Policy.',
    'ach_email_prompt' => 'Please enter your email address:',
    'verification_pending' => 'Verification Pending',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'More options',
    'credit_card' => 'Credit Card',
    'bank_transfer' => 'Bank Transfer',
    'no_transaction_reference' => 'We did not recieve a payment transaction reference from the gateway.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'This invoice will automatically be billed to the payment method on file on the due date.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Added :date',
    'failed_remove_payment_method' => 'Failed to remove the payment method',
    'gateway_exists' => 'This gateway already exists',
    'manual_entry' => 'Manual entry',
    'start_of_week' => 'Primer Día de la Semana',

    // Frequencies
    'freq_inactive' => 'Inactivo',
    'freq_daily' => 'Diario',
    'freq_weekly' => 'Weekly',
    'freq_biweekly' => 'Quincenal',
    'freq_two_weeks' => 'Two weeks',
    'freq_four_weeks' => 'Four weeks',
    'freq_monthly' => 'Mensual',
    'freq_three_months' => 'Tres meses',
    'freq_four_months' => 'Cuatro meses',
    'freq_six_months' => 'Seis meses',
    'freq_annually' => 'Annually',
    'freq_two_years' => 'Dos años',

    // Payment types
    'payment_type_Apply Credit' => 'Apply Credit',
    'payment_type_Bank Transfer' => 'Bank Transfer',
    'payment_type_Cash' => 'Cash',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Credit Card Other',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Silbido',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'Débito Directo SEPA',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Advertising',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energy',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Government',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Insurance',
    'industry_Manufacturing' => 'Manufacturing',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Pharmaceuticals',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Real Estate',
    'industry_Restaurant & Catering' => 'Restaurante & catering',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transportation',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Other',
    'industry_Photography' => 'Photography',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'España',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Croatian',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Español - España',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Griego',
    'lang_English - United Kingdom' => 'Inglés - Reino Unido',
    'lang_English - Australia' => 'Inglés - Australia',
    'lang_Slovenian' => 'Esloveno',
    'lang_Finnish' => 'Finlandés',
    'lang_Romanian' => 'Romano',
    'lang_Turkish - Turkey' => 'Turco - Turquía',
    'lang_Portuguese - Brazilian' => 'Portugués - Brasil',
    'lang_Portuguese - Portugal' => 'Portugués - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonio',
    'lang_Chinese - Taiwan' => 'Chino - Taiwan',
    'lang_Serbian' => 'Serbio',
    'lang_Bulgarian' => 'Búlgaro',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Accounting & Legal',
    'industry_Advertising' => 'Advertising',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Banking & Finance',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energy',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Government',
    'industry_Healthcare & Life Sciences' => 'Healthcare & Life Sciences',
    'industry_Insurance' => 'Insurance',
    'industry_Manufacturing' => 'Manufacturing',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit & Higher Ed',
    'industry_Pharmaceuticals' => 'Pharmaceuticals',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Real Estate',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transportation',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Other',
    'industry_Photography' => 'Photography',

    'view_client_portal' => 'View client portal',
    'view_portal' => 'View Portal',
    'vendor_contacts' => 'Contactos de Proveedor',
    'all' => 'All',
    'selected' => 'Selected',
    'category' => 'Category',
    'categories' => 'Categories',
    'new_expense_category' => 'New Expense Category',
    'edit_category' => 'Edit Category',
    'archive_expense_category' => 'Archive Category',
    'expense_categories' => 'Expense Categories',
    'list_expense_categories' => 'List Expense Categories',
    'updated_expense_category' => 'Successfully updated expense category',
    'created_expense_category' => 'Successfully created expense category',
    'archived_expense_category' => 'Successfully archived expense category',
    'archived_expense_categories' => 'Successfully archived :count expense category',
    'restore_expense_category' => 'Restore expense category',
    'restored_expense_category' => 'Successfully restored expense category',
    'apply_taxes' => 'Apply taxes',
    'min_to_max_users' => ':min to :max users',
    'max_users_reached' => 'The maximum number of users has been reached.',
    'buy_now_buttons' => 'Buy Now Buttons',
    'landing_page' => 'Landing Page',
    'payment_type' => 'Payment Type',
    'form' => 'Form',
    'link' => 'Link',
    'fields' => 'Fields',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Nota: el cliente y la factura se crean aún cuando la transacción no se completa.',
    'buy_now_buttons_disabled' => 'This feature requires that a product is created and a payment gateway is configured.',
    'enable_buy_now_buttons_help' => 'Enable support for buy now buttons',
    'changes_take_effect_immediately' => 'Note: changes take effect immediately',
    'wepay_account_description' => 'Payment gateway for Invoice Ninja',
    'payment_error_code' => 'There was an error processing your payment [:code]. Please try again later.',
    'standard_fees_apply' => 'Tarifa: 2.9%/1.2% [Tarjeta de Crédito/Transferencia Bancaria] + $0.30 por cargo exitoso.',
    'limit_import_rows' => 'Data needs to be imported in batches of :count rows or less',
    'error_title' => 'Something went wrong',
    'error_contact_text' => 'If you\'d like help please email us at :mailaddress',
    'no_undo' => 'Warning: this can\'t be undone.',
    'no_contact_selected' => 'Please select a contact',
    'no_client_selected' => 'Please select a client',

    'gateway_config_error' => 'It may help to set new passwords or generate new API keys.',
    'payment_type_on_file' => ':type on file',
    'invoice_for_client' => 'Invoice :invoice for :client',
    'intent_not_found' => 'Sorry, I\'m not sure what you\'re asking.',
    'intent_not_supported' => 'Sorry, I\'m not able to do that.',
    'client_not_found' => 'I wasn\'t able to find the client',
    'not_allowed' => 'Sorry, you don\'t have the needed permissions',
    'bot_emailed_invoice' => 'Your invoice has been sent.',
    'bot_emailed_notify_viewed' => 'I\'ll email you when it\'s viewed.',
    'bot_emailed_notify_paid' => 'I\'ll email you when it\'s paid.',
    'add_product_to_invoice' => 'Adicionar 1 :producto',
    'not_authorized' => 'You are not authorized',
    'bot_get_email' => 'Hola! (wave)<br/>Gracias por intentar usar el Bot de Invoice Ninja<br/>Para poder usar este bot necesitas crear un cuenta gratuíta.<br/>Envíame la dirección de correo de tu cuenta para que empecemos.',
    'bot_get_code' => 'Thanks! I\'ve sent a you an email with your security code.',
    'bot_welcome' => 'That\'s it, your account is verified.<br/>',
    'email_not_found' => 'I wasn\'t able to find an available account for :email',
    'invalid_code' => 'The code is not correct',
    'security_code_email_subject' => 'Security code for Invoice Ninja Bot',
    'security_code_email_line1' => 'This is your Invoice Ninja Bot security code.',
    'security_code_email_line2' => 'Note: it will expire in 10 minutes.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'Lista de Productos',

    'include_item_taxes_inline' => 'Include <b>line item taxes in line total</b>',
    'created_quotes' => 'Successfully created :count quotes(s)',
    'limited_gateways' => 'Nota: admitimos una pasarela de pago de tarjeta de crédito por empresa.',

    'warning' => 'Warning',
    'self-update' => 'Update',
    'update_invoiceninja_title' => 'Update Invoice Ninja',
    'update_invoiceninja_warning' => 'Before start upgrading Invoice Ninja create a backup of your database and files!',
    'update_invoiceninja_available' => 'A new version of Invoice Ninja is available.',
    'update_invoiceninja_unavailable' => 'No new version of Invoice Ninja available.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Update now',
    'update_invoiceninja_download_start' => 'Download :version',
    'create_new' => 'Create New',

    'toggle_navigation' => 'Toggle Navigation',
    'toggle_history' => 'Toggle History',
    'unassigned' => 'Unassigned',
    'task' => 'Task',
    'contact_name' => 'Contact Name',
    'city_state_postal' => 'City/State/Postal',
    'custom_field' => 'Custom Field',
    'account_fields' => 'Campos de Empresa',
    'facebook_and_twitter' => 'Facebook and Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds to help support our project',
    'reseller_text' => 'Nota: la licencia etiqueta-blanca está pensada para uso personal, por favor, envíenos un email a :email si está interesado en revender la app.',
    'unnamed_client' => 'Unnamed Client',

    'day' => 'Day',
    'week' => 'Week',
    'month' => 'Mes',
    'inactive_logout' => 'You have been logged out due to inactivity',
    'reports' => 'Informes',
    'total_profit' => 'Total Profit',
    'total_expenses' => 'Total Expenses',
    'quote_to' => 'Quote to',

    // Limits
    'limit' => 'Limit',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'No Limits',
    'set_limits' => 'Set :gateway_type Limits',
    'enable_min' => 'Enable min',
    'enable_max' => 'Enable max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'This invoice does not meet the limits for that payment type.',

    'date_range' => 'Date Range',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Update',
    'invoice_fields_help' => 'Drag and drop fields to change their order and location',
    'new_category' => 'New Category',
    'restore_product' => 'Restaurar Producto',
    'blank' => 'Blank',
    'invoice_save_error' => 'Hubo un error al guardar su factura.',
    'enable_recurring' => 'Enable Recurring',
    'disable_recurring' => 'Disable Recurring',
    'text' => 'Text',
    'expense_will_create' => 'expense will be created',
    'expenses_will_create' => 'expenses will be created',
    'created_expenses' => 'Successfully created :count expense(s)',

    'translate_app' => 'Ayúdenos con las traducciones desde :link',
    'expense_category' => 'Categoría de Gastos',

    'go_ninja_pro' => 'Ir a Ninja Pro!',
    'go_enterprise' => 'Ir a modo empresa!',
    'upgrade_for_features' => 'Actualícese De Versión Para Más Funcionalidades',
    'pay_annually_discount' => 'Pague anualmente por 10 meses y obtenga 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'SuMarca.invoiceninja.com',
    'pro_upgrade_feature2' => 'Personalice cada aspecto de su factura!',
    'enterprise_upgrade_feature1' => 'Asigne permisos para múltiples usuarios',
    'enterprise_upgrade_feature2' => 'Adjunte archivos de terceros a facturas y gastos',
    'much_more' => 'Mucho mas!',
    'all_pro_fetaures' => 'Más todas las funcionalidades del plan pro!',

    'currency_symbol' => 'Símbolo',
    'currency_code' => 'Codigo',

    'buy_license' => 'Comprar Licencia',
    'apply_license' => 'Activar Licencia',
    'submit' => 'Enviar',
    'white_label_license_key' => 'Llave de la Licencia',
    'invalid_white_label_license' => 'La  licencia de etiqueta blanca no es válida',
    'created_by' => 'Creado por :name',
    'modules' => 'Módulos',
    'financial_year_start' => 'Primer Mes del Año',
    'authentication' => 'Autenticación',
    'checkbox' => 'Casilla',
    'invoice_signature' => 'Firma',
    'show_accept_invoice_terms' => 'Casilla de los Términos de la Factura',
    'show_accept_invoice_terms_help' => 'Requerir que el cliente confirme que aceptó los términos de la factura.',
    'show_accept_quote_terms' => 'Casilla de los Términos de la Cotización',
    'show_accept_quote_terms_help' => 'Requerir que el cliente confirme que aceptó los términos de la cotización.',
    'require_invoice_signature' => 'Firma de la Facturra',
    'require_invoice_signature_help' => 'Requerir que el cliente provea su firma.',
    'require_quote_signature' => 'Firma de la Cotización',
    'require_quote_signature_help' => 'Requerir que el cliente provea su firma.',
    'i_agree' => 'Estoy de Acuerdo con los Términos',
    'sign_here' => 'Por favor firme aquí:',
    'authorization' => 'Autorización',
    'signed' => 'Firmado',

    // BlueVine
    'bluevine_promo' => 'Obtenga líneas de cŕedito flexibles y factoring de facturas usando BlueVine.',
    'bluevine_modal_label' => 'Inscríbase con BlueVine',
    'bluevine_modal_text' => '<h3>Rápida financiación para su Negocio. Sin papeleo.</h3>
<ul><li>Líneas de cŕedito flexibles y factoring.</li></ul>',
    'bluevine_create_account' => 'Cree una cuenta',
    'quote_types' => 'Obtenga una cotización para',
    'invoice_factoring' => 'Factoring de facturas',
    'line_of_credit' => 'Línea de crédito',
    'fico_score' => 'Su puntuación FICO',
    'business_inception' => 'Fecha de Creación del Negocio',
    'average_bank_balance' => 'Promedio del saldo de la cuenta bancaria',
    'annual_revenue' => 'Ingresos anuales',
    'desired_credit_limit_factoring' => 'Límite de factoring de facturas deseado',
    'desired_credit_limit_loc' => 'Límite de línea de crédito deseado',
    'desired_credit_limit' => 'Límite de crédito deseado',
    'bluevine_credit_line_type_required' => 'Debe seleccionar al menos una',
    'bluevine_field_required' => 'Este campo es requerido',
    'bluevine_unexpected_error' => 'Un error inesperado ha ocurrido.',
    'bluevine_no_conditional_offer' => 'Más información es requerida para obtener una cotización. Haga clic en continuar a continuación.',
    'bluevine_invoice_factoring' => 'Factoring de facturas',
    'bluevine_conditional_offer' => 'Oferta Condicional',
    'bluevine_credit_line_amount' => 'Línea de Crédito',
    'bluevine_advance_rate' => 'Tasa Avanzada',
    'bluevine_weekly_discount_rate' => 'Tasa de Descuento Semanal',
    'bluevine_minimum_fee_rate' => 'Cuota Mínima',
    'bluevine_line_of_credit' => 'Línea de Crédito ',
    'bluevine_interest_rate' => 'Tasa de Interéz',
    'bluevine_weekly_draw_rate' => 'Tasa de Retiro Semanal',
    'bluevine_continue' => 'Continúe a BlueVine',
    'bluevine_completed' => 'Inscripción en BlueVine completa',

    'vendor_name' => 'Proveedor',
    'entity_state' => 'Estado',
    'client_created_at' => 'Fecha de Creación',
    'postmark_error' => 'Hubo un problema enviando el correo a través de Postmark :link',
    'project' => 'Proyecto',
    'projects' => 'Proyectos',
    'new_project' => 'Nuevo Proyecto',
    'edit_project' => 'Editar Proyecto',
    'archive_project' => 'Archivar Proyecto',
    'list_projects' => 'Listar Proyectos',
    'updated_project' => 'Proyecto actualizado con éxito',
    'created_project' => 'Proyecto creado con éxito',
    'archived_project' => 'Proyecto archivado con éxito',
    'archived_projects' => 'Archivados con éxito :count proyectos',
    'restore_project' => 'Restaurar Proyecto',
    'restored_project' => 'Proyecto restaurado con éxito',
    'delete_project' => 'Eliminar Proyecto',
    'deleted_project' => 'Proyecto eliminado con éxito',
    'deleted_projects' => 'Eliminados con éxito :count proyectos',
    'delete_expense_category' => 'Eliminar categoría',
    'deleted_expense_category' => 'Categoría actualizada con éxito',
    'delete_product' => 'Eliminar Producto',
    'deleted_product' => 'Producto actualizado con éxito',
    'deleted_products' => 'Eliminados con éxito :count productos',
    'restored_product' => 'Producto restaurado con éxito',
    'update_credit' => 'Actualizar Crédito',
    'updated_credit' => 'Crédito actualizado con éxito',
    'edit_credit' => 'Editar Crédito',
    'realtime_preview' => 'Vista Previa en Tiempo Real',
    'realtime_preview_help' => 'Actualice la vista previa del PDF en tiempo real en la página de la factura al editarla. Deshabilite esto para mejorar el rendimiento al editar las facturas.',
    'live_preview_help' => 'Mostrar una vista previa en tiempo real del PDF en la página de la factura.',
    'force_pdfjs_help' => 'Reemplazar el visor de archivos PDF incorporado de :chrome_link y :firefox_link. <br/> Habilite esto si su navegador está descargando automáticamente el archivo PDF.',
    'force_pdfjs' => 'Prevenir Descarga',
    'redirect_url' => 'URL de Redirección',
    'redirect_url_help' => 'Opcionalmente, especifique una URL para redireccionar luego que se ingrese el pago.',
    'save_draft' => 'Guardar Borrador',
    'refunded_credit_payment' => 'Pago de crédito reembolsado',
    'keyboard_shortcuts' => 'Atajos de Teclado',
    'toggle_menu' => 'Alternar Menú',
    'new_...' => 'Nuevo ...',
    'list_...' => 'Listar ...',
    'created_at' => 'Fecha de Creación',
    'contact_us' => 'Contáctenos',
    'user_guide' => 'Guía de Usuario',
    'promo_message' => 'Actualícese antes de :expires y obtenga :amount de descuento en su primer año con nuestros paquetes Pro o Enterprise.',
    'discount_message' => ':amount de descuento expira en :expira',
    'mark_paid' => 'Marcar como Pagado',
    'marked_sent_invoice' => 'Factura marcada como enviada con éxito',
    'marked_sent_invoices' => 'Facturas marcadas como enviadas con éxito',
    'invoice_name' => 'Factura',
    'product_will_create' => 'el producto será creado',
    'contact_us_response' => 'Gracias por su mensaje! Intentaremos responderle lo antes posible.',
    'last_7_days' => 'Últimos 7 días',
    'last_30_days' => 'Últimos 30 Días',
    'this_month' => 'Este Mes',
    'last_month' => 'Mes Anterior',
    'current_quarter' => 'Trimerstre Actual',
    'last_quarter' => 'Último Trimestre',
    'last_year' => 'Año Anterior',
    'custom_range' => 'Rango Personalizado',
    'url' => 'URL',
    'debug' => 'Depurar',
    'https' => 'HTTPS',
    'require' => 'Requerir',
    'license_expiring' => 'Nota: Su licencia expira en :count días, renuévela en :link',
    'security_confirmation' => 'Su dirección de correo electrónico ha sido confirmada',
    'white_label_expired' => 'Su licencia de etiqueta blanca ha expirado, por favor considere renovarla para ayudar a soportar a nuestro proyecto.',
    'renew_license' => 'Renovar Licencia',
    'iphone_app_message' => 'Considere descargando nuestro :link',
    'iphone_app' => 'app para iPhone',
    'android_app' => 'App Android',
    'logged_in' => 'Conectado',
    'switch_to_primary' => 'Cámbiese a su empresa principal (:name) para administrar su plan.',
    'inclusive' => 'Inclusivo',
    'exclusive' => 'Exclusivo',
    'postal_city_state' => 'Código Postal/Ciudad/Estado',
    'phantomjs_help' => 'En algunos casos la aplicación usa :link_phantom para el PDF, instale :link_docs para generarlo localmente.',
    'phantomjs_local' => 'Usar PhantomJS local',
    'client_number' => 'Cliente Número',
    'client_number_help' => 'Especifique un prefijo o use un patrón personalizado para asignar dinámicamente el número de cliente.',
    'next_client_number' => 'El siguiente número de cliente es :number.',
    'generated_numbers' => 'Números Generados',
    'notes_reminder1' => 'Primer Recordatorio',
    'notes_reminder2' => 'Segundo Recordatorio',
    'notes_reminder3' => 'Tercer Recordatorio',
    'notes_reminder4' => 'Recordatorio',
    'bcc_email' => 'Correo para Copia Oculta BCC',
    'tax_quote' => 'Cotización con Impuestos',
    'tax_invoice' => 'Factura con Impuestos',
    'emailed_invoices' => 'Facturas enviadas por correo electrónico con éxito.',
    'emailed_quotes' => 'Cotizaciones enviadas por correo electrónico con éxito.',
    'website_url' => 'Dirección del Sitio Web',
    'domain' => 'Dominio',
    'domain_help' => 'Usado en el portal de clientes y al enviar correos electrónicos.',
    'domain_help_website' => 'Usado al enviar correos electrónicos.',
    'import_invoices' => 'Importar Facturas',
    'new_report' => 'Nuevo Reporte',
    'edit_report' => 'Editar Reporte',
    'columns' => 'Columnas',
    'filters' => 'Filtros',
    'sort_by' => 'Ordenar Por',
    'draft' => 'Borrador',
    'unpaid' => 'Sin Pagar',
    'aging' => 'Envejecimiento',
    'age' => 'Edad',
    'days' => 'Días',
    'age_group_0' => '0 - 30 Días',
    'age_group_30' => '30 - 60 Días',
    'age_group_60' => '60 - 90 Días',
    'age_group_90' => '90 - 120 Días',
    'age_group_120' => '120+ Días',
    'invoice_details' => 'Detalles de la Factura',
    'qty' => 'Cantidad',
    'profit_and_loss' => 'Ganancias y Pérdidas',
    'revenue' => 'Ingresos',
    'profit' => 'Ganancia',
    'group_when_sorted' => 'Ordenar por Grupo',
    'group_dates_by' => 'Agrupar Fechas Por',
    'year' => 'Año',
    'view_statement' => 'Ver Estado De Cuenta',
    'statement' => 'Estado De Cuenta',
    'statement_date' => 'Fecha del Estado De Cuenta',
    'mark_active' => 'Marcar como Activo',
    'send_automatically' => 'Enviar Automáticamente',
    'initial_email' => 'Email Inicial',
    'invoice_not_emailed' => 'Esta factura no ha sido enviada.',
    'quote_not_emailed' => 'Esta cotización no ha sido enviada.',
    'sent_by' => 'Enviada por :user',
    'recipients' => 'Remitentes',
    'save_as_default' => 'Guardar como predeterminado',
    'start_of_week_help' => 'Usado por los selectores de <b>fecha</b>',
    'financial_year_start_help' => 'Usado por los selectores de <b>rango de fecha</b>',
    'reports_help' => 'Shift + Click para ordenar por múltiples columnas, Ctrl + Click para desactivar la agrupación.',
    'this_year' => 'Este Año',

    // Updated login screen
    'ninja_tagline' => 'Crear. Enviar. Recibir Pago.',
    'login_or_existing' => 'O ingrese con una cuenta conectada.',
    'sign_up_now' => 'Cree Una Cuenta Ahora',
    'not_a_member_yet' => 'Aún no tiene una cuenta?',
    'login_create_an_account' => 'Crear una Cuenta!',

    // New Client Portal styling
    'invoice_from' => 'Facturas de:',
    'email_alias_message' => 'Requerimos que cada empresa tenga una dirección de correo electrónico única<br/>Considera usar un alias ej, email+label@example.com',
    'full_name' => 'Nombre Completo',
    'month_year' => 'MES/AÑO',
    'valid_thru' => 'Válido\nhasta',

    'product_fields' => 'Campos de Producto',
    'custom_product_fields_help' => 'Agregar un campo al crear un producto o factura y la etiqueta visible y el valor en el PDF.',
    'freq_two_months' => 'Dos meses',
    'freq_yearly' => 'Anualmente',
    'profile' => 'Perfil',
    'payment_type_help' => 'Establecer el <b>tipo de pago manual</b> por defecto.',
    'industry_Construction' => 'Construcción',
    'your_statement' => 'Su Estado Financiero',
    'statement_issued_to' => 'Estado de Cuenta emitido a',
    'statement_to' => 'Estado de Cuenta para',
    'customize_options' => 'Personalizar opciones',
    'created_payment_term' => 'Término de pago creado con éxito',
    'updated_payment_term' => 'Término de pago actualizado con éxito',
    'archived_payment_term' => 'Término de pago archivado con éxito',
    'resend_invite' => 'Reenviar Invitación',
    'credit_created_by' => 'Crédito creado por el pago :transaction_reference',
    'created_payment_and_credit' => 'Pago y Crédito creados con éxito',
    'created_payment_and_credit_emailed_client' => 'Pago y Crédito creados con éxito, y el cliente ha sido notificado por correo',
    'create_project' => 'Crear proyecto',
    'create_vendor' => 'Crear Proveedor',
    'create_expense_category' => 'Crear categoría',
    'pro_plan_reports' => ':link para habilitar los reportes actualizándose al Plan Pro',
    'mark_ready' => 'Marcar como Listo',

    'limits' => 'Límites',
    'fees' => 'Tarifas',
    'fee' => 'Tarifa',
    'set_limits_fees' => 'Configure los Límites/Tarifas de :gateway_type',
    'fees_tax_help' => 'Habilite impuestos por linea para definir las tasas de impuestos.',
    'fees_sample' => 'La tarifa para una factura con valor de :amount sería de :total.',
    'discount_sample' => 'El descuento para una factura con valor de :amount sería de :total.',
    'no_fees' => 'Sin Tarifas',
    'gateway_fees_disclaimer' => 'Advertencia: no todos los estados/pasarelas de pago permiten agregar tarifas, por favor revisa tu leyes locales/términos de servicio.',
    'percent' => 'Porciento',
    'location' => 'Ubicación',
    'line_item' => 'Item de Linea',
    'surcharge' => 'Sobrecargo',
    'location_first_surcharge' => 'Habilitado - Primer sobrecargo',
    'location_second_surcharge' => 'Habilitado - Segundo sobrecargo',
    'location_line_item' => 'Habilitado - Item de Linea',
    'online_payment_surcharge' => 'Sobrecargo por Pago en Linea',
    'gateway_fees' => 'Tarifas de Pasarela de Pagos',
    'fees_disabled' => 'Las tarifas están deshabilitadas',
    'gateway_fees_help' => 'Agregar automáticamente un sobrecargo/descuento por pago en linea.',
    'gateway' => 'Pasarela de Pagos',
    'gateway_fee_change_warning' => 'Si hay facturas pendientes por pagar con tarifas estas necesitan ser actualizadas manualmente.',
    'fees_surcharge_help' => 'Personalizar sobrecargos :link.',
    'label_and_taxes' => 'etiquetas e impuestos',
    'billable' => 'Cobrable',
    'logo_warning_too_large' => 'La imagen es muy grande.',
    'logo_warning_fileinfo' => 'Advertencia: para poder soportar imágenes tipo gif, la extensión de PHP fileinfo debe ser habilitada.',
    'logo_warning_invalid' => 'Hubo un problema leyendo el archivo de la imagen, por favor intente con un formato diferente.',

    'error_refresh_page' => 'Ha ocurrido un error, por favor refresca la página e intenta de nuevo.',
    'data' => 'Datos',
    'imported_settings' => 'Preferencias importadas con éxito',
    'reset_counter' => 'Reiniciar Contador',
    'next_reset' => 'Siguiente Reinicio',
    'reset_counter_help' => 'Reiniciar automáticamente los contadores de factura y cotización.',
    'auto_bill_failed' => 'Falló la auto-facturación para la factura :invoice_number',
    'online_payment_discount' => 'Descuento por Pago En Linea',
    'created_new_company' => 'Nueva empresa creada con éxito',
    'fees_disabled_for_gateway' => 'Las tarifas están deshabilitadas para esta pasarela de pago.',
    'logout_and_delete' => 'Salir/Borrar Cuenta',
    'tax_rate_type_help' => 'Las tasas impositivas incluyentes ajustan el costo de la línea de pedido cuando se seleccionan.<br/>Solo las tasas de impuestos exclusivas se pueden usar de manera predeterminada.',
    'invoice_footer_help' => 'Use $pageNumber y $pageCount para ver la información de la página.',
    'credit_note' => 'Nota de Crédito',
    'credit_issued_to' => 'Crédito emitido a',
    'credit_to' => 'Crédito para',
    'your_credit' => 'Tu Crédito',
    'credit_number' => 'Número de Crédito',
    'create_credit_note' => 'Crear Nota de Crédito',
    'menu' => 'Menú',
    'error_incorrect_gateway_ids' => 'Error: La tabla de pasarelas de pago tiene identificadores incorrectos.',
    'purge_data' => 'Purgar Datos',
    'delete_data' => 'Borrar Datos',
    'purge_data_help' => 'Borrar permanentemente todos los datos pero mantener la cuenta y su configuración.',
    'cancel_account_help' => 'Borrar permanentemente la cuenta con datos y configuración.',
    'purge_successful' => 'Datos de la empresa purgados con éxito',
    'forbidden' => 'Prohibído',
    'purge_data_message' => 'Advertencia: Esto borrará definitivamente tus datos, no hay de deshacerlo.',
    'contact_phone' => 'Teléfono de Contacto',
    'contact_email' => 'Correo de Contacto',
    'reply_to_email' => 'Correo de Respuesta',
    'reply_to_email_help' => 'Especifica la dirección de respuesta para los correos electrónicos de los clientes.',
    'bcc_email_help' => 'Incluir de manera privada esta dirección con los correos de los clientes.',
    'import_complete' => 'Tu importe se ha completado con éxito.',
    'confirm_account_to_import' => 'Por favor confirma tu cuenta para importar los datos.',
    'import_started' => 'Tu importación ha empezado, te enviaremos un correo cuando termine.',
    'listening' => 'Escuchando...',
    'microphone_help' => 'Dí "nueva factura para [cliente]" o "muéstrame los pagos archivados de [cliente]"',
    'voice_commands' => 'Comandos de Voz',
    'sample_commands' => 'Comandos de muestra',
    'voice_commands_feedback' => 'Estamos trabajando activamente para mejorar esta función, si hay un comando que te gustaría que soportemos, envíanos un correo electrónico a: email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Giro Postal',
    'archived_products' => ':count productos archivados con éxito',
    'recommend_on' => 'Nosotros recomendamos <b>habilitar</b> esta función.',
    'recommend_off' => 'Nosotros recomendamos <b>deshabilitar</b> esta función.',
    'notes_auto_billed' => 'Auto-facturado',
    'surcharge_label' => 'Etiqueta de Sobrecargo',
    'contact_fields' => 'Campos de Contacto',
    'custom_contact_fields_help' => 'Agregar un campo al crear un contacto y, opcionalmente, mostrar la etiqueta y el valor en el PDF.',
    'datatable_info' => 'Mostrando de :start a :end de :total entradas',
    'credit_total' => 'Crédito Total',
    'mark_billable' => 'Marcar como facturable',
    'billed' => 'Facturado',
    'company_variables' => 'Variables de Empresa',
    'client_variables' => 'Variables de Cliente',
    'invoice_variables' => 'Variables de Factura',
    'navigation_variables' => 'Variables de Navegación',
    'custom_variables' => 'Variables Personalizadas',
    'invalid_file' => 'Tpo de archivo inválido',
    'add_documents_to_invoice' => 'Agregar documentos a la factura',
    'mark_expense_paid' => 'Marcar como Pagado',
    'white_label_license_error' => 'Error al validar la licencia, verifica el archivo de log storage/logs/laravel-error.log para más detalles.',
    'plan_price' => 'Precio del Plan',
    'wrong_confirmation' => 'Código de confirmación incorrecto',
    'oauth_taken' => 'La cuenta ya ha sido registrada',
    'emailed_payment' => 'Pago enviado por correo con éxito',
    'email_payment' => 'Enviar Pago por Correo Electrónico',
    'invoiceplane_import' => 'Use :link para migrar tus datos desde InvoicePlane.',
    'duplicate_expense_warning' => 'Advertencia: Este :link puede ser un duplicado',
    'expense_link' => 'gasto',
    'resume_task' => 'Reanudar Tarea',
    'resumed_task' => 'Tarea reanudada con éxito',
    'quote_design' => 'Diseño de Cotización',
    'default_design' => 'Diseño Estándar',
    'custom_design1' => 'Diseño Personalizado 1',
    'custom_design2' => 'Diseño Personalizado 2',
    'custom_design3' => 'Diseño Personalizado 3',
    'empty' => 'Vacío',
    'load_design' => 'Cargar Diseño',
    'accepted_card_logos' => 'Logos de Tarjetas Aceptadas',
    'phantomjs_local_and_cloud' => 'Usando PhantomJS local, volviendo a phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Llave de Google Analytics',
    'analytics_key_help' => 'Seguimiento de pagos usando :link',
    'start_date_required' => 'La fecha de inicio es requerida',
    'application_settings' => 'Configuración de Aplicación',
    'database_connection' => 'Conexión a la Base de Datos',
    'driver' => 'Driver',
    'host' => 'Servidor',
    'database' => 'Base de Datos',
    'test_connection' => 'Probar Conección',
    'from_name' => 'Nombre Remitente',
    'from_address' => 'Dirección Remitente',
    'port' => 'Puerto',
    'encryption' => 'Encripción',
    'mailgun_domain' => 'Dominio de Mailgun',
    'mailgun_private_key' => 'Llave Privada de Mailgun',
    'send_test_email' => 'Enviar correo de prueba',
    'select_label' => 'Seleccionar Etiqueta',
    'label' => 'Etiqueta',
    'service' => 'Servicio',
    'update_payment_details' => 'Actualizar los detalles del pago',
    'updated_payment_details' => 'Detalles del pago actualizados con éxito',
    'update_credit_card' => 'Actualizar Tarjeta de Crédito',
    'recurring_expenses' => 'Gastos Recurrentes',
    'recurring_expense' => 'Gasto Recurrente',
    'new_recurring_expense' => 'Nuevo Gasto Recurrente',
    'edit_recurring_expense' => 'Editar Gasto Recurrente',
    'archive_recurring_expense' => 'Archivar Gasto Recurrente',
    'list_recurring_expense' => 'Listar Gastos Recurrentes',
    'updated_recurring_expense' => 'Gasto recurrente actualizado con éxito',
    'created_recurring_expense' => 'Gasto recurrente creado con éxito',
    'archived_recurring_expense' => 'Gasto recurrente archivado con éxito',
    'restore_recurring_expense' => 'Restaurar Gasto Recurrente',
    'restored_recurring_expense' => 'Gasto recurrente restaurado con éxito',
    'delete_recurring_expense' => 'Eliminar Gasto Recurrente',
    'deleted_recurring_expense' => 'Proyecto eliminado con éxito',
    'view_recurring_expense' => 'Ver Gasto Recurrente',
    'taxes_and_fees' => 'Impuestos y Tarifas',
    'import_failed' => 'Importación fallida',
    'recurring_prefix' => 'Prefijo Recurrente',
    'options' => 'Opciones',
    'credit_number_help' => 'Especifica un prefijo o usa un patrón personalizado para establecer dinámicamente el número de crédito para las facturas negativas.',
    'next_credit_number' => 'El número de crédito es :number.',
    'padding_help' => 'Cantidad de ceros para rellenar el número.',
    'import_warning_invalid_date' => 'Advertencia: El formato de fecha parece ser inválido.',
    'product_notes' => 'Notas de Producto',
    'app_version' => 'Versión de la Aplicación',
    'ofx_version' => 'Versión de OFX',
    'gateway_help_23' => ':link para obtener tus llaves del API de Stripe.',
    'error_app_key_set_to_default' => 'Error: APP_KEY está configurado con un valor por defecto, para actualizarlo haz un backup de la base de datos y después ejecuta el comando  <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Cobrar Tarifa por Tardanza',
    'late_fee_amount' => 'Valor Tarifa por Tardanza',
    'late_fee_percent' => 'Porcentaje Tarifa por Tardanza',
    'late_fee_added' => 'Tarifa por Tardanza agregada el :date',
    'download_invoice' => 'Descargar factura',
    'download_quote' => 'Descargar Cotización',
    'invoices_are_attached' => 'Los archivos PDF de tu factura están adjuntos.',
    'downloaded_invoice' => 'Un correo electrónico será enviado con el archivo PDF de la factura',
    'downloaded_quote' => 'Un correo electrónico será enviado con el archivo PDF de la cotización',
    'downloaded_invoices' => 'Un correo electrónico será enviado con los archivos PDF de la factura',
    'downloaded_quotes' => 'Un correo electrónico será enviado con los archivos PDF de la cotización',
    'clone_expense' => 'Clonar Gasto',
    'default_documents' => 'Documentos por defecto',
    'send_email_to_client' => 'Enviar correo electrónico al cliente',
    'refund_subject' => 'Reembolso Procesado',
    'refund_body' => 'Se te ha procesado un reembolso de: monto de la factura: invoice_number.',

    'currency_us_dollar' => 'Dólar Americano',
    'currency_british_pound' => 'Libra Británica',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Rand Sudafricano',
    'currency_danish_krone' => 'Corona Danesa',
    'currency_israeli_shekel' => 'Shekel israelí',
    'currency_swedish_krona' => 'Corona Sueca',
    'currency_kenyan_shilling' => 'Chelín de Kenia',
    'currency_canadian_dollar' => 'Dólar Canadiense',
    'currency_philippine_peso' => 'Peso Filipino',
    'currency_indian_rupee' => 'Rupia India',
    'currency_australian_dollar' => 'Dólar Australiano',
    'currency_singapore_dollar' => 'Dólar de Singapur',
    'currency_norske_kroner' => 'Corona Noruega',
    'currency_new_zealand_dollar' => 'Dólar Neozelandés',
    'currency_vietnamese_dong' => 'dong Vietnamita',
    'currency_swiss_franc' => 'Franco Suizo',
    'currency_guatemalan_quetzal' => 'Quetzal Guatemalteco',
    'currency_malaysian_ringgit' => 'Ringgit de Malasia',
    'currency_brazilian_real' => 'Real Brasileño',
    'currency_thai_baht' => 'Baht Tailandés',
    'currency_nigerian_naira' => 'Naira Nigeriano',
    'currency_argentine_peso' => 'Peso Argentino',
    'currency_bangladeshi_taka' => 'Taka de Bangladesh',
    'currency_united_arab_emirates_dirham' => 'Dirham de Emiratos Arabes Unidos',
    'currency_hong_kong_dollar' => 'Dólar de Hong Kong',
    'currency_indonesian_rupiah' => 'Rupia de Indonesia',
    'currency_mexican_peso' => 'Peso Mexicano',
    'currency_egyptian_pound' => 'Libra Egipcia',
    'currency_colombian_peso' => 'Peso Colombiano',
    'currency_west_african_franc' => 'Franco de África del Oeste',
    'currency_chinese_renminbi' => 'Renminbi Chino',
    'currency_rwandan_franc' => 'Franco Ruandés',
    'currency_tanzanian_shilling' => 'Chelín Tanzano',
    'currency_netherlands_antillean_guilder' => 'Florín de las Antillas Holandesas',
    'currency_trinidad_and_tobago_dollar' => 'Dólar de Trinidad y Tobago',
    'currency_east_caribbean_dollar' => 'Dólar del Caribe del Este',
    'currency_ghanaian_cedi' => 'Cedi Ghanés',
    'currency_bulgarian_lev' => 'Lev búlgaro',
    'currency_aruban_florin' => 'Florín de Aruba',
    'currency_turkish_lira' => 'Lira Tturca',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Kuna Croata',
    'currency_saudi_riyal' => 'Riyal Saudita',
    'currency_japanese_yen' => 'Riyal Saudita',
    'currency_maldivian_rufiyaa' => 'Rufiyaa Maldiva',
    'currency_costa_rican_colon' => 'Colón Costarricense',
    'currency_pakistani_rupee' => 'Rupia Pakistaní',
    'currency_polish_zloty' => 'Zloty Polaco',
    'currency_sri_lankan_rupee' => 'Rupia de Sri Lanka',
    'currency_czech_koruna' => 'Corona Checa',
    'currency_uruguayan_peso' => 'Peso Uruguayo',
    'currency_namibian_dollar' => 'Dólar de Namibia',
    'currency_tunisian_dinar' => 'Dinar Tunecino',
    'currency_russian_ruble' => 'Rublo Ruso',
    'currency_mozambican_metical' => 'Metical Mozambiqueño',
    'currency_omani_rial' => 'Rial Omaní',
    'currency_ukrainian_hryvnia' => 'Ucrania Grivna',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Nuevo Dólar Taiwanés',
    'currency_dominican_peso' => 'Peso Dominicano',
    'currency_chilean_peso' => 'Peso Chileno',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Sol Peruano',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Dólar de Barbados',
    'currency_brunei_dollar' => 'Dólar de Brunei',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Lempira Hondureño',
    'currency_surinamese_dollar' => 'Dólar Surinamés',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Bolívar Venezolano',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Dólar Jamaiquino',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'Esperamos que estés disfrutando de usar la aplicación.<br/>Si consideras  :link lo apreciaremos mucho!',
    'writing_a_review' => 'escribiendo una reseña',

    'use_english_version' => 'Asegúrate de usar la versión en Ingles de los archivos. <br/> Nosotros usamos los encabezados de las columnas para que coincidan con los campos.',
    'tax1' => 'Primera Impuesto',
    'tax2' => 'Segundo Impuesto',
    'fee_help' => 'Las tarifas de Pasarela de Pago son los costos que se cobran por el acceso a las redes financieras que manejan el procesamiento de pagos en línea.',
    'format_export' => 'Exportando formato',
    'custom1' => 'Primero Personalizado',
    'custom2' => 'Segundo Personalizado',
    'contact_first_name' => 'Primer Nombre de Contacto',
    'contact_last_name' => 'Apellido de Contacto',
    'contact_custom1' => 'Primero Contacto Personalizado',
    'contact_custom2' => 'Segundo Contacto Personalizado',
    'currency' => 'Moneda',
    'ofx_help' => 'Para solucionar problemas busca comentarios en :ofxhome_link y prueba con :ofxget_link.',
    'comments' => 'comentarios',

    'item_product' => 'Producto del Concepto',
    'item_notes' => 'Notas del concepto',
    'item_cost' => 'Costo del Concepto',
    'item_quantity' => 'Cantidad del Concepto',
    'item_tax_rate' => 'Tasa de Impuesto del Concepto',
    'item_tax_name' => 'Nombre del Impuesto del Concepto',
    'item_tax1' => 'Impuesto1 Concepto',
    'item_tax2' => 'Impuesto2 Concepto',

    'delete_company' => 'Eliminar Empresa',
    'delete_company_help' => 'Eliminar de manera permanente la empresa con todos sus datos y configuración.',
    'delete_company_message' => 'Advertencia: Esto eliminará su empresa, no hay manera de deshacerlo.',

    'applied_discount' => 'El cupón ha sido aplicado, el precio del plan ha sido reducido a :discount%.',
    'applied_free_year' => 'El cupón ha sido aplicado,  tu cuenta ha sido actualizada al plan Pro por un año.',

    'contact_us_help' => 'SI estás reportando un error por favor incluye los logs relevantes de storage/logs/laravel-error.log',
    'include_errors' => 'Incluir Errores',
    'include_errors_help' => 'Incluir :link de storage/logs/laravel-error.log',
    'recent_errors' => 'errores recientes',
    'customer' => 'Cliente',
    'customers' => 'Clientes',
    'created_customer' => 'Cliente creado con éxito',
    'created_customers' => 'Creados :count clientes con éxito',

    'purge_details' => 'La información en tu empresa (:account) ha sido purgada con éxito.',
    'deleted_company' => 'Empresa eliminada con éxito',
    'deleted_account' => 'Cuenta cancelada con éxito',
    'deleted_company_details' => 'Su empresa (:account) ha sido eliminada con éxito.',
    'deleted_account_details' => 'Tu cuenta (:account) ha sido eliminada con éxito.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'Débito Directo SEPA',
    'enable_alipay' => 'Aceptar Alipay',
    'enable_sofort' => 'Aceptar transferencias bancarias de EU',
    'stripe_alipay_help' => 'Estas pasarelas de pago deben ser activadas en :link',
    'calendar' => 'Calendario',
    'pro_plan_calendar' => ':link para habilitar el calendario al acceder al Plan Pro.',

    'what_are_you_working_on' => 'En qué estás trabajando ?',
    'time_tracker' => 'Contador de Tiempo',
    'refresh' => 'Refrescar',
    'filter_sort' => 'Filtrar/Ordenar',
    'no_description' => 'Sin Descripción',
    'time_tracker_login' => 'Login del Contador de Tiempo',
    'save_or_discard' => 'Guardar o descartar tus camboi',
    'discard_changes' => 'Descartar Cambios',
    'tasks_not_enabled' => 'Las tareas no están habilitadas.',
    'started_task' => 'Tarea iniciada con éxito',
    'create_client' => 'Crear Cliente',

    'download_desktop_app' => 'Descargar la aplicación de escritorio',
    'download_iphone_app' => 'Descargar la aplicación para iPhone',
    'download_android_app' => 'escargar la aplicación para Android',
    'time_tracker_mobile_help' => 'Doble click en una tarea para seleccionarla',
    'stopped' => 'Detenido',
    'ascending' => 'Ascendente',
    'descending' => 'Descendente',
    'sort_field' => 'Ordenar Por',
    'sort_direction' => 'Dirección',
    'discard' => 'Descartar',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'minutos',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Limpiar',
    'warn_payment_gateway' => 'Nota: para aceptar pagos en linea requieres de una pasarela de pago configurada. :link para agregar una.',
    'task_rate' => 'Tasa de Tarea',
    'task_rate_help' => 'Configurar la tasa por defecto para las tareas involucradas.',
    'past_due' => 'Vencido',
    'document' => 'Documento',
    'invoice_or_expense' => 'Factura/Gasto',
    'invoice_pdfs' => 'PDF\'s de Factura',
    'enable_sepa' => 'Aceptar SEPA',
    'enable_bitcoin' => 'Aceptar Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Al proporcionar su número IBAN y confirmar este pago, está autorizando a: la empresa y a Stripe, nuestro proveedor de servicios de pago, a enviar instrucciones a su banco para cargar a su cuenta y a su banco para debitar su cuenta de acuerdo con esas instrucciones. Tiene derecho a un reembolso de su banco en los términos y condiciones del acuerdo con este. Se debe reclamar un reembolso dentro de las 8 semanas a partir de la fecha en que se debitó su cuenta.',
    'recover_license' => 'Recuperar Liciencia',
    'purchase' => 'Compra',
    'recover' => 'Recuperar',
    'apply' => 'Aplicar',
    'recover_white_label_header' => 'Recuperar Licencia Blanca',
    'apply_white_label_header' => 'Aplicar Licencia Blanca',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Volver a la Factura',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Fecha de Vencimiento Parcial',
    'task_fields' => 'Campos de la Tarea',
    'product_fields_help' => 'Arrastra y suelta los campos para cambiar su orden',
    'custom_value1' => 'Valor Personalizado',
    'custom_value2' => 'Valor Personalizado',
    'enable_two_factor' => 'Autenticación de Dos Factores',
    'enable_two_factor_help' => 'Usa tu teléfono para confirmar tu identidad al ingresar',
    'two_factor_setup' => 'Configuración de Autenticación de Dos Factores',
    'two_factor_setup_help' => 'Escanee el código de barras con una aplicación compatible con :link ',
    'one_time_password' => 'Contraseña de una sola vez',
    'set_phone_for_two_factor' => 'Configura tu teléfono como backup para habilitarlo.',
    'enabled_two_factor' => 'Autenticación de Dos Factores habilitada con éxito',
    'add_product' => 'Agregar Producto',
    'email_will_be_sent_on' => 'Nota: El correo será enviado en :date.',
    'invoice_product' => 'Producto de Factura',
    'self_host_login' => 'Inicio de Sesión en Servidor Propio',
    'set_self_hoat_url' => 'URL de Servidor Propio',
    'local_storage_required' => 'Error: storage el local no está disponible.',
    'your_password_reset_link' => 'Tu link parara Resetear la Contraseña',
    'subdomain_taken' => 'El subdominio ya está en uso',
    'client_login' => 'Inicio de Sesión del Cliente',
    'converted_amount' => 'Cantidad Convertida',
    'default' => 'Por Defecto',
    'shipping_address' => 'Dirección de Envío',
    'bllling_address' => 'Dirección de Facturación',
    'billing_address1' => 'Calle de Facturación',
    'billing_address2' => 'Apto/Suite de Facturación',
    'billing_city' => 'Ciudad de Facturación',
    'billing_state' => 'Estado/Provincia de Facturación',
    'billing_postal_code' => 'Código Postal de Facturación',
    'billing_country' => 'País de Facturación',
    'shipping_address1' => 'Calle de Envío',
    'shipping_address2' => 'Apto/Suite de Envío',
    'shipping_city' => 'Ciudad de Envío',
    'shipping_state' => 'Estado/Provincia de Envío',
    'shipping_postal_code' => 'Código Postal de Envío',
    'shipping_country' => 'País de Envío',
    'classify' => 'Clasificar',
    'show_shipping_address_help' => 'Requerir que el cliente indique su dirección de envío',
    'ship_to_billing_address' => 'Enviar a la dirección de envío',
    'delivery_note' => 'Nota de Entrega',
    'show_tasks_in_portal' => 'Mostrar tareas en el portal de cliente',
    'cancel_schedule' => 'Cancelar Programación',
    'scheduled_report' => 'Programar Reporte',
    'scheduled_report_help' => 'Enviar por correo el reporte :report como :format a :email',
    'created_scheduled_report' => 'Reporte programado con éxito',
    'deleted_scheduled_report' => 'Programaci;on de reporte cancelada con éxito',
    'scheduled_report_attached' => 'Su reporte programado de :type está adjunto.',
    'scheduled_report_error' => 'Error al crear el reporte programado',
    'invalid_one_time_password' => 'Clave inicial inválida',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Acepta Apple Pay y Google Pay',
    'requires_subdomain' => 'Este tipo de pago requiere un :link.',
    'subdomain_is_set' => 'subdominio configurado',
    'verification_file' => 'Archivo de Verificación',
    'verification_file_missing' => 'Se requiere el archivo de verificación para aceptar pagos.',
    'apple_pay_domain' => 'Usa <code>:domain</code> como dominio en :link.',
    'apple_pay_not_supported' => 'Disculpe, su navegador no soporta Apple/Google Pay',
    'optional_payment_methods' => 'Métodos de Pago Opcionales',
    'add_subscription' => 'Agregar suscripción',
    'target_url' => 'Objetivo',
    'target_url_help' => 'Cuando ocurra el evento seleccionado, la aplicación publicará la entidad en la URL objetivo.',
    'event' => 'Evento',
    'subscription_event_1' => 'Cliente Creado',
    'subscription_event_2' => 'Factura Creada',
    'subscription_event_3' => 'Cotización Creada',
    'subscription_event_4' => 'Pago Creado',
    'subscription_event_5' => 'Proveedor Creado',
    'subscription_event_6' => 'Presupuesto actualizado',
    'subscription_event_7' => 'Presupuesto eliminado',
    'subscription_event_8' => 'Factura actualizada',
    'subscription_event_9' => 'Factura eliminada',
    'subscription_event_10' => 'Cliente actualizado',
    'subscription_event_11' => 'Cliente eliminado',
    'subscription_event_12' => 'Pago eliminado',
    'subscription_event_13' => 'Proveedor Actualizado',
    'subscription_event_14' => 'Proveedor Borrado',
    'subscription_event_15' => 'Gasto creado',
    'subscription_event_16' => 'Gasto actualizado',
    'subscription_event_17' => 'Gasto eliminado',
    'subscription_event_18' => 'Tarea creada',
    'subscription_event_19' => 'Tarea actualizada',
    'subscription_event_20' => 'Tarea eliminada',
    'subscription_event_21' => 'Presupuesto aprobado',
    'subscriptions' => 'Suscripciones',
    'updated_subscription' => 'Suscripción actualizada correctamente',
    'created_subscription' => 'Suscripción creada correctamente',
    'edit_subscription' => 'Editar suscripción',
    'archive_subscription' => 'Archivar suscripción',
    'archived_subscription' => 'Suscripción correctamente archivada',
    'project_error_multiple_clients' => 'Los proyectos no pueden pertenecer a otro cliente',
    'invoice_project' => 'Facturar proyecto',
    'module_recurring_invoice' => 'Facturas recurrentes',
    'module_credit' => 'Créditos',
    'module_quote' => 'Presupuestos & Propuestas',
    'module_task' => 'Tareas & Proyectos',
    'module_expense' => 'Gastos y Proveedores',
    'module_ticket' => 'Tickets',
    'reminders' => 'Recordatorios',
    'send_client_reminders' => 'Enviar recordatorios por email',
    'can_view_tasks' => 'Las tareas son visibles en el portal',
    'is_not_sent_reminders' => 'Los recordatorios no son enviados',
    'promotion_footer' => 'Tu promoción caducará pronto, :link para actualizar ahora.',
    'unable_to_delete_primary' => 'Nota: para eliminar esta empresa primero elimine todas las empresas enlazadas.',
    'please_register' => 'Por favor registre su cuenta',
    'processing_request' => 'Procesando solicitud',
    'mcrypt_warning' => 'Aviso: Mcrypt está obsoleto, ejecuta :command para actualizar tu cifrado.',
    'edit_times' => 'Editar tiempos',
    'inclusive_taxes_help' => 'Incluir <b>impuestos en el coste</b>',
    'inclusive_taxes_notice' => 'Esta opción no puede ser cambiada una vez se ha creado una factura.',
    'inclusive_taxes_warning' => 'Aviso: hay que volver a guardar facturas existentes',
    'copy_shipping' => 'Copiar envío',
    'copy_billing' => 'Copiar facturación',
    'quote_has_expired' => 'El presupuesto ha expirado, por favor contacta con el comercio.',
    'empty_table_footer' => 'Mostrando 0 a 0 de 0 entradas',
    'do_not_trust' => 'No recordar este dispositivo',
    'trust_for_30_days' => 'Recordar por 30 días',
    'trust_forever' => 'Recordar para siempre',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Listo para hacer',
    'in_progress' => 'En progreso',
    'add_status' => 'Añadir estado',
    'archive_status' => 'Estado Archivado',
    'new_status' => 'Estado Nuevo',
    'convert_products' => 'Convertir productos',
    'convert_products_help' => 'Convertir automáticamente precios de los productos a la moneda del cliente',
    'improve_client_portal_link' => 'Configura un subdominio para acortar el enlace al portal de cliente.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progreso',
    'view_project' => 'Ver proyecto',
    'summary' => 'Sumario',
    'endless_reminder' => 'Recordatorio sin fin',
    'signature_on_invoice_help' => 'Añade el siguiente código para mostrar la firma del cliente en el PDF.',
    'signature_on_pdf' => 'Ver en PDF',
    'signature_on_pdf_help' => 'Mostrar la firma del cliente en los PDF de facturas/presupuestos.',
    'expired_white_label' => 'Ha expirado la licencia de marca blanca',
    'return_to_login' => 'Volver al Acceso',
    'convert_products_tip' => 'Nota: añade un :link con nombre ":name" para ver la tasa de conversión.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Usa <code>Etiqueta|Opción1,Opción2</code> para mostrar una caja de selección.',
    'client_information' => 'Información del cliente',
    'updated_client_details' => 'Detalles del cliente actualizados correctamente',
    'auto' => 'Auto',
    'tax_amount' => 'Suma de Impuestos',
    'tax_paid' => 'Impuestos pagados',
    'none' => 'Ninguno',
    'proposal_message_button' => 'Para ver tu propuesta de :amount, haz clic en el enlace de abajo.',
    'proposal' => 'Propuesta',
    'proposals' => 'Propuestas',
    'list_proposals' => 'Listar propuestas',
    'new_proposal' => 'Nueva propuesta',
    'edit_proposal' => 'Editar propuesta',
    'archive_proposal' => 'Archivar propuesta',
    'delete_proposal' => 'Borrar propuesta',
    'created_proposal' => 'Propuesta creada correctamente',
    'updated_proposal' => 'Propuesta actualizada correctamente',
    'archived_proposal' => 'Propuesta archivada correctamente',
    'deleted_proposal' => 'Propuesta archivada correctamente',
    'archived_proposals' => ':count propuestas archivadas correctamente',
    'deleted_proposals' => ':count propuestas archivadas correctamente',
    'restored_proposal' => 'Propuesta restaurada correctamente',
    'restore_proposal' => 'Restaurar propuesta',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'Nuevo Snippet',
    'edit_proposal_snippet' => 'Editar Snippet',
    'archive_proposal_snippet' => 'Archivar Snippet',
    'delete_proposal_snippet' => 'Borrar Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Plantilla',
    'templates' => 'Plantillas',
    'proposal_template' => 'Plantilla',
    'proposal_templates' => 'Plantillas',
    'new_proposal_template' => 'Nueva plantilla',
    'edit_proposal_template' => 'Editar plantilla',
    'archive_proposal_template' => 'Archivar plantilla',
    'delete_proposal_template' => 'Borrar plantilla',
    'created_proposal_template' => 'Plantilla creada correctamente',
    'updated_proposal_template' => 'Plantilla actualizada correctamente',
    'archived_proposal_template' => 'Plantilla archivada correctamente',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Plantilla restaurada correctamente',
    'restore_proposal_template' => 'Restaurar Plantilla',
    'proposal_category' => 'Categoría',
    'proposal_categories' => 'Categorías',
    'new_proposal_category' => 'Nueva categoría',
    'edit_proposal_category' => 'Editar categoría',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Cargando',
    'no_messages_found' => 'No se ha encontrado ningún mensaje',
    'processing' => 'Procesando',
    'reactivate' => 'Reactivar',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Abierto',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'Has recibido un nuevo pago!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'El proveedor será creado',
    'vendors_will_create' => 'proveedores serán creados',
    'created_vendors' => ':count proveedor(es) creado(s) con éxito',
    'import_vendors' => 'Importar Proveedores',
    'company' => 'Empresa',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Campo Proveedor',
    'company_field' => 'Campo de Empresa',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Agregue un campo al crear un proveedor',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Comparar',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Periodo de Comparación',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Comparar con',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Valor de Empresa',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtro por Proveedor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Empresa Personalizada 1',
    'company2' => 'Empresa Personalizada 2',
    'company3' => 'Empresa Personalizada 3',
    'company4' => 'Empresa Personalizada 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Seleccionar Empresa',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Está Eliminado',
    'vendor_city' => 'Ciudad del Proveedor',
    'vendor_state' => 'Estado del Proveedor',
    'vendor_country' => 'País del Proveedor',
    'credit_footer' => 'Pie de Página del Crédito',
    'credit_terms' => 'Términos del Crédito',
    'untitled_company' => 'Empresa sin Nombre',
    'added_company' => 'Empresa agregada con éxito',
    'supported_events' => 'Eventos Soportados',
    'custom3' => 'Tercero Personalizado',
    'custom4' => 'Cuarto Personalizado',
    'optional' => 'Opcional',
    'license' => 'Licencia',
    'invoice_balance' => 'Balance de la Factura',
    'saved_design' => 'Diseño guardado con éxito',
    'client_details' => 'Detalles del Cliente',
    'company_address' => 'Dirección de la Empresa',
    'quote_details' => 'Detalles de la Cotización',
    'credit_details' => 'Detalles del Crédito',
    'product_columns' => 'Columna de Productos',
    'task_columns' => 'Columna de Tareas',
    'add_field' => 'Agregar Campos',
    'all_events' => 'Todos los Eventos',
    'owned' => 'Propiedad',
    'payment_success' => 'Pago Exitóso',
    'payment_failure' => 'Fallos con el Pago',
    'quote_sent' => 'Cotización Enviada',
    'credit_sent' => 'Crédito Enviado',
    'invoice_viewed' => 'Factura Vista',
    'quote_viewed' => 'Crédito Visto',
    'credit_viewed' => 'Crédito Visto',
    'quote_approved' => 'Cotización Aprobada',
    'receive_all_notifications' => 'Recibir Todas Las Notificaciones',
    'purchase_license' => 'Comprar Licencia',
    'enable_modules' => 'Habilitar Módulos',
    'converted_quote' => 'Cotización convertida con éxito',
    'credit_design' => 'Diseño de Créditos',
    'includes' => 'Incluir',
    'css_framework' => 'Framework de CSS',
    'custom_designs' => 'Diseños Personalizados',
    'designs' => 'Diseños',
    'new_design' => 'Nuevo Diseño',
    'edit_design' => 'Editar Diseño',
    'created_design' => 'Diseño creado con éxito',
    'updated_design' => 'Diseño actualizado con éxito',
    'archived_design' => 'Diseño archivado con éxito',
    'deleted_design' => 'Diseño eliminado con éxito',
    'removed_design' => 'Diseño removido con éxito',
    'restored_design' => 'Diseño restaurado con éxito',
    'recurring_tasks' => 'Tareas Recurrentes',
    'removed_credit' => 'Crédito removido con éxito',
    'latest_version' => 'Últiima Versión',
    'update_now' => 'Actualizarse Ahora',
    'a_new_version_is_available' => 'Una nueva versión de la aplicación está disponible',
    'update_available' => 'Actualización Disponible',
    'app_updated' => 'Actualización completada con éxito',
    'integrations' => 'Integraciones',
    'tracking_id' => 'Id de Rastreo',
    'slack_webhook_url' => 'URL del Webhook de Slack',
    'partial_payment' => 'Pago Parcial',
    'partial_payment_email' => 'Correo Electrónico de Pago Parcial',
    'clone_to_credit' => 'Clonar como Crédito',
    'emailed_credit' => 'Crédito enviado por correo electrónico con éxito',
    'marked_credit_as_sent' => 'Crédito marcado como enviado con éxito',
    'email_subject_payment_partial' => 'Asunto del correo electrónico de pago parcial',
    'is_approved' => 'Está Aprobado',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Buscar Proveedor',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Actualizar Proveedor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Registro de Cliente',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Buscar 1 Proveedor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'URL de Registro',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmación',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
